*********************************************************************************
**** Historical Patterns of Inequality and Productivity around Financial Crises
**** by Pascal Paul
**** December 2021
**** This File: Analysis of Aftermath Part
*********************************************************************************

set mem 400m
set more off
clear all
clear mata
clear matrix
eststo clear

global root "C:\Users\l1pxp07\Desktop\December 2021"
cd "$root"

*** Choose functions to run
local process_data					= 0 // Run data processing programs
global exclude_wars 				= 1 // Exclude wars from data

local typical_output_response		= 1
local local_proj_comb				= 1 // Run local projections all recessions

if `process_data' == 1 {

	do "$root/Data/Programs/PROCESS_ALL_DATA.do"
}

*** set measures
global measures llp incT1
use "$root\Data\Output\Dataset_aftermath.dta", clear

cd "$root"

* force sort tsset again
sort ccode year
tsset ccode year, yearly

*** Create the year constraints for the two sample periods
local c1 year>=1870

replace cay = 100*cay

* RHS 7 variable set
local rhs7 	dlrprv 	dlrgdp 	 dlpc 	 dlriy 	 stir 	ltrate 	 cay   debtgdp ///
			l.dlrprv l.dlrgdp l.dlpc l.dlriy l.stir l.ltrate l.cay l.debtgdp

local rhslevels dlrprv dlrgdp dlpc dlriy stir ltrate cay debtgdp

*** Impulse response variables
local irvars	lrgdp

*** creating cumulative change variables
forvalues i=1/5 {
	foreach v of local irvars {
		gen lrgdp`i' = 100*(f`i'.lrgdp - lrgdp)
		lab var lrgdp`i' "`i'"
	}
}

*** Measures of Excess credit, TFP, LP, income share top 1%, income share top 10%
local measures $measures

*** Locals for saving files
local tlrgdp 			"GDP"

*** table labels
local rvar_lrgdp 		"Real GDP per capita"
local rvar_llp 			"Labour Productivity"
local varlablrgdp 		"y"
local varlabllp 		"LP"

*** Measures of Excess credit, TFP, LP, income share top 1%, income share top 10%
local measures $measures

local lmllp 			"LP measure"
local lmincT1			"Income share top 1 measure"

*** Define Variables
cd "$root/Data/Input/Recession Dates Data/"

qui include annual_brybos_loop.do

local yvars lrgdp llp income_top1
local cycle bb

qui include amplitude_201204.do

gen srx_llp = .
replace srx_llp = llp - L3.llp
lab var srx_llp "LP growth measure"

gen srx_incT1 = .
replace srx_incT1 = income_top1 - L3.income_top1
lab var srx_incT1 "Income share top 1% excess measure"

gen pk_comb = pk_norm + pk_fin

foreach d of local measures {
	gen srx_norm_`d' = srx_`d'*pk_norm
	gen srx_fin_`d'  = srx_`d'*pk_fin
	gen srx_comb_`d' = srx_`d'*pk_comb
}

gen core = 1 if (year>=1870&year<=1908) | (year>=1921&year<=1933) | (year>=1948&year<=2008)

replace core = . if pk_norm==0 & pk_fin==0
replace core = . if f1.lrgdp==.
replace core = . if f2.lrgdp==.
replace core = . if f3.lrgdp==.
replace core = . if f4.lrgdp==.
replace core = . if f5.lrgdp==.

* main sample all & postwar
local c1 core==1
local c2 core==1 & year>1945

* demean by bin to standardize the treatment terms individually
foreach var of local measures {
	sum srx_norm_`var' if pk_norm==1 & core==1 // ****** demean within norm bin
	replace srx_norm_`var' = srx_norm_`var' - r(mean) if pk_norm==1 & core
	global mean_norm_`var' = r(mean)

	sum srx_fin_`var' if pk_fin==1 & core==1 // ****** demean within fin bin
	replace srx_fin_`var' = srx_fin_`var' - r(mean) if pk_fin==1 & core
	global mean_fin_`var' = r(mean)
	
	sum srx_comb_`var' if pk_comb==1 & core==1 // ****** demean within norm bin
	replace srx_comb_`var' = srx_comb_`var' - r(mean) if pk_comb==1 & core
	global mean_comb_`var' = r(mean)
}

gen dincome_top1_1_5lag = L1.income_top1 - L5.income_top1
gen dllp_1_5lag 		= L1.llp - L5.llp

gen srx_crisis_llp 		= crisisJST*dllp_1_5lag
gen srx_crisis_incT1 	= crisisJST*dincome_top1_1_5lag

cd "$root/Aftermath/"

*******************************
* Typical Behavior Recessions *
*******************************

if `typical_output_response' == 1 {
		
	foreach var in incT1 llp {
		qui gen 	tempv1 = srx_comb_`var' 		if pk_comb == 1 & core
		qui egen 	tempv2 = std(tempv1) 			if pk_comb == 1 & core
		qui gen 	srx_comb_`var'_std = tempv2  	if pk_comb == 1 & core
		qui drop 	tempv1 tempv2
	}
	
	foreach var in incT1 llp {
		gen high_`var'_comb = .
		replace high_`var'_comb = 1 if srx_comb_`var'_std > 1 	& pk_comb == 1
		replace high_`var'_comb = 0 if srx_comb_`var'_std < -1 	& pk_comb == 1
	}
	
	preserve
	
	local desc0 "low"
	local desc1 "high"
	
	foreach var in incT1 llp {
		foreach i in 0 1 {
				restore
				preserve
				
				forvalues n = 1/5 {
					sum lrgdp`n' if pk_comb == 1 & high_`var'_comb==`i'
					matrix def lrgdp`n'_pk_comb_`var'_`desc`i'' = (r(mean))
				}
				
				matrix lrgdp_pk_comb_`var'_`desc`i'' = lrgdp1_pk_comb_`var'_`desc`i''
				
				forvalues n = 2/5 {
					matrix lrgdp_pk_comb_`var'_`desc`i'' = (lrgdp_pk_comb_`var'_`desc`i'',lrgdp`n'_pk_comb_`var'_`desc`i'')
				}
				
				drop _all
				svmat lrgdp_pk_comb_`var'_`desc`i''
				
				xpose, clear
				
				rename v1 pk_comb_`var'_`desc`i''
				gen t = _n
				order t
				
				tempfile comb_`var'_`desc`i''
				save `comb_`var'_`desc`i'''
			}

		use `comb_`var'_low', clear
		merge 1:1 t using `comb_`var'_high', nogen
				
		drop t
		xpose, clear
		gen zero = 0
		order zero
		export delimited using "$root/Aftermath/Temp Files/Typical_GDP_Response_`var'.csv" , delim(",") replace novar
		
	}
	restore
}

**************************************************************
*** Local Projections without controlling for excess credit **
*** All Recessions 											**
*** Labor productivity and income share top 1% measures		**
**************************************************************

if `local_proj_comb' == 1 {

	local measures llp incT1
	local irvars lrgdp
	
	preserve
	
	foreach m of local measures {
		local M
		if "`m'"=="llp"			local M "LP"
		if "`m'"=="incT1"		local M "IncomeShareTop1"

		if inlist("`m'","incT1") {
			local sign +
		}
		if inlist("`m'","llp") {
			local sign -
		}

		********************************************
		** Complete set of IRFs for all variables **
		********************************************
			
		restore
		preserve
		
		* 7 variable LP Conditional
		* with 1 se shock to excess credit in each bin
		* full set of IRFs

		*** generate the coefficient columns to be filled in with the results below
		foreach v of local irvars {
			forvalues j=1/1 {
				
				* setup normal and normal +1sd excess 
				gen bn0_`v'_`p`j''=0
				gen sen0_`v'_`p`j''=0
				gen bn1_`v'_`p`j''=0
				gen sen1_`v'_`p`j''=0
			}
		}
		
		forvalues j=1/1 {   // full sample = c1
			foreach v of local irvars {
				forvalues i =1/5 {
				
					local `v'_diff`i'
					local `v'_pval`i'
					local `v'_se`i'
					local `v'_stars`i'
					
					local `v'_excR_b`i'
					local `v'_excR_se`i'
					local `v'_excR_p`i'
					local `v'_excR_stars`i'
					
					qui reg `v'`i' pk_comb srx_comb_`m' `rhs7' ///
						if `c`j'' & core==1, noconstant
					gen reg_sample = e(sample)
					
					foreach var in `rhslevels' {
						qui gen `var'_`v' = `var' if reg_sample==1
						qui gen L`var'_`v' = l.`var' if reg_sample==1
						
						qui gen tempv1 = `var'_`v'
						qui egen tempv2 = std(tempv1)
						qui replace `var'_`v' = tempv2
						qui drop tempv1 tempv2
						
						qui gen tempv1 = L`var'_`v'
						qui egen tempv2 = std(tempv1)
						qui replace L`var'_`v' = tempv2
						qui drop tempv1 tempv2
					}
					
					foreach var in srx_comb_`m' {
							qui gen tempv1 = `var' if reg_sample==1
							qui egen tempv2 = std(tempv1) if reg_sample==1
							qui gen `var'_`v'=tempv2  if reg_sample==1
							qui drop tempv1 tempv2
					}
					
					drop reg_sample

					local rhs7_`v' ""
					foreach var in `rhslevels' {
						local rhs7_`v' = "`rhs7_`v'' `var'_`v' L`var'_`v'"
					}

					reg `v'`i' pk_comb srx_comb_`m'_`v' `rhs7_`v'' ///
						if `c`j'' & core==1, noconstant

					replace bn0_`v'_`p`j''  = _b[pk_comb] if _n == `i'+1
					replace sen0_`v'_`p`j'' = _se[pk_comb] if _n == `i'+1

					lincom pk_comb `sign' (1.5*srx_comb_`m'_`v')
					replace bn1_`v'_`p`j''  = r(estimate) if _n == `i'+1
					replace sen1_`v'_`p`j'' = r(se)       if _n == `i'+1

					*** new
					testparm pk_comb
					local pk_comb_p = r(p)
					local pk_comb_stars
					if `pk_comb_p'<0.10 {
						local pk_comb_stars = "*"
					}
					if `pk_comb_p'<0.05 {
						local pk_comb_stars = "**"
					}
					if `pk_comb_p'<0.01 {
						local pk_comb_stars = "***"
					}
					
					testparm srx_comb_`m'_`v'
					local `v'_excR_b`i' = _b[srx_comb_`m'_`v']
					local `v'_excR_se`i' = _se[srx_comb_`m'_`v']
					local `v'_excR_p`i' = r(p)
					
					local `v'_excR_stars`i'
					if ``v'_excR_p`i''<0.1 {
						local `v'_excR_stars`i' = "*"
					}
					if ``v'_excR_p`i''<0.05 {
						local `v'_excR_stars`i' = "**"
					}
					if ``v'_excR_p`i''<0.01 {
						local `v'_excR_stars`i' = "***"
					}
					
					sum pk_comb if e(sample)
					estadd scalar comb = r(sum)
					local N_comb = r(sum)
					
					local Nmaxstars = max(length("`pk_comb_stars'"),length("``v'_excR_stars`i''"))
					di `Nmaxstars'
					local maxstars 
					if `Nmaxstars'==1 {
						local maxstars = "*"
					}
					if `Nmaxstars'==2 {
						local maxstars = "**"
					}
					if `Nmaxstars'==3 {
						local maxstars = "***"
					}
					di "`maxstars'"
					
					foreach x in pk_comb_stars `v'_excR_stars`i' {
						local `x'_add 
						if (`Nmaxstars'-length("``x''"))==1 {
							local `x'_add = "*"
						}
						if (`Nmaxstars'-length("``x''"))==2 {
							local `x'_add = "**"
						}
						if (`Nmaxstars'-length("``x''"))==3 {
							local `x'_add = "***"
						}
					}
					
					foreach y in pk_comb srx_comb_`m'_`v' {
						local `y'_neg = "\textcolor{white}{-}"

						local `y'bneg
						if _b[`y']>=0 {
							local `y'bneg = "\textcolor{white}{-}"
						}
					}
					
					estadd local space = " "
					estadd local hline = ""
					
					estadd local R_beta = "`pk_combbneg'`:di %4.3f _b[pk_comb]'`pk_comb_stars'\textcolor{white}{`pk_comb_stars_add'}"
					estadd local R_beta_se = "`pk_comb_neg'(`:di %4.3f _se[pk_comb]')\textcolor{white}{`maxstars'}"
					
					estadd local Excess_`m'_beta = "`srx_comb_`m'_`v'bneg'`:di %4.3f _b[srx_comb_`m'_`v']'``v'_excR_stars`i''\textcolor{white}{``v'_excR_stars`i'_add'}"
					estadd local Excess_`m'_beta_se = "`srx_comb_`m'_`v'_neg'(`:di %4.3f _se[srx_comb_`m'_`v']')\textcolor{white}{`maxstars'}"
					
					estadd local CombN = "\textcolor{white}{-}`N_comb'\textcolor{white}{`maxstars'}"
					
					eststo h`i'
					
					foreach var in `rhslevels' {
						drop `var'_`v' L`var'_`v'
					}
					drop srx_comb_`m'_`v'
				}
				
				local llp_desc "\mathrm{log(LP)_{t}}"
				local incT1_desc "\mathrm{Income \ Share \ 1 \%_{t}}"
				
				#delimit ;
				esttab h1 h2 h3 h4 h5 using "$root/Aftermath/Tables/IRF_`t`v''_`M'_measure_combined_recessions.tex", replace se 
				nocons nogaps eqlabels(none) label nonumbers nomtitles
				drop(pk_* srx* L* dlrprv* dl* dlpc* dlriy* stir* ltrate* cay* debtgdp*)
				star(* 0.1 ** 0.05 *** 0.01)
				stats(space
					  R_beta
					  R_beta_se
					  space
					  Excess_`m'_beta
					  Excess_`m'_beta_se
					  space
					  hline
					  CombN
					  , 
					  layout(@ @ @ @ @ @ @ @ @ @)
						 fmt(3 3 3 3 3 3 3 3 3 0)
				l(" & "
				  "Average Recession & $\hat{\beta}^{h}$"
				  " & "
				  " & "
				  "$\Delta_3 ``m'_desc'$ & $\hat{\gamma}^{h}$"
				  " & "
				  " & "
				  "\hline"
				  "\multicolumn{2}{l}{Observations}"
				  )) ;
				#delimit cr;
			}			
		}
		
		local keep = ""
		foreach v of local irvars {
			local keep = `" `keep' bn0_`v'_`p1' bn1_`v'_`p1' "'
		}
		global keep = "`keep'"
		drop if _n>6
		order $keep
		keep $keep
		
		xpose, clear
		export delimited "$root/Aftermath/Temp Files/Pooled_Recessions_`M'_measure_IRFs.csv", delim(",") novar replace
	}
	restore
}

graph close _all
