
********************************************
*** Process Reinhart-Rogoff Crises Dates ***
********************************************

set more off

cd "$root"

*** A thru E
foreach c in ///
	Algeria Angola Argentina Australia Austria Belgium Bolivia ///
	Brazil Canada CentralAfricanRep Chile China Colombia CostaRica ///
	CoteDIvoire Denmark DominicanRepublic Ecuador Egypt ElSalvador {
	
	import excel "Data/Input/Crises Dates Data/RR_crisis_dates_A-E.xls", sheet("`c'") cellrange(A17:I227) clear

	keep A H
	rename A year
	rename H crisisRR
	gen str30 country = "`c'"
	order year country crisisRR
	tempfile `c'
	save ``c''
}

local i = 1
foreach c in ///
	Algeria Angola Argentina Australia Austria Belgium Bolivia ///
	Brazil Canada CentralAfricanRep Chile China Colombia CostaRica ///
	CoteDIvoire Denmark DominicanRepublic Ecuador Egypt ElSalvador {

	if `i'==1 {
		use ``c'', clear
	}
	else {
		append using ``c''
	}
	local i = `i' + 1
}
replace country = "Central African Republic" if country=="CentralAfricanRep"
replace country = "Costa Rica" if country=="CostaRica"
replace country = "Ivory Coast" if country=="CoteDIvoire"
replace country = "Dominican Republic" if country=="DominicanRepublic"
replace country = "El Salvador" if country=="ElSalvador"

tempfile AE
save `AE'

*** F thru M
foreach c in ///
	Finland France Germany Ghana Greece Guatemala Honduras ///
	Hungary Iceland India Indonesia Ireland Italy Japan ///
	Kenya Korea Malaysia Mauritius Mexico Morocco {
	
	import excel "Data/Input/Crises Dates Data/RR_crisis_dates_F-M.xls", sheet("`c'") cellrange(A17:I227) clear
	keep A H
	rename A year
	rename H crisisRR
	gen str30 country = "`c'"
	order year country crisisRR
	tempfile `c'
	save ``c''
}

local i = 1
foreach c in ///
	Finland France Germany Ghana Greece Guatemala Honduras ///
	Hungary Iceland India Indonesia Ireland Italy Japan ///
	Kenya Korea Malaysia Mauritius Mexico Morocco {

	if `i'==1 {
		use ``c'', clear
	}
	else {
		append using ``c''
	}
	local i = `i' + 1
}

tempfile FM
save `FM'

*** M thru S
foreach c in ///
	Myanmar Netherlands NewZealand Nicaragua Nigeria Norway ///
	Panama Paraguay Peru Philippines Poland Portugal Romania ///
	Russia Singapore SouthAfrica Spain SriLanka Sweden Switzerland {
	
	import excel "Data/Input/Crises Dates Data/RR_crisis_dates_M-S.xls", sheet("`c'") cellrange(A17:I227) clear
	keep A H
	rename A year
	rename H crisisRR
	gen str30 country = "`c'"
	order year country crisisRR
	tempfile `c'
	save ``c''
}

local i = 1
foreach c in ///
	Myanmar Netherlands NewZealand Nicaragua Nigeria Norway ///
	Panama Paraguay Peru Philippines Poland Portugal Romania ///
	Russia Singapore SouthAfrica Spain SriLanka Sweden Switzerland {

	if `i'==1 {
		use ``c'', clear
	}
	else {
		append using ``c''
	}
	local i = `i' + 1
}
replace country = "New Zealand" if country=="NewZealand"
replace country = "South Africa" if country=="SouthAfrica"
replace country = "Sri Lanka" if country=="SriLanka"

tempfile MS
save `MS'

*** T thru Z
foreach c in ///
	Taiwan Thailand Tunisia Turkey UK US Uruguay Venezuela Zambia Zimbabwe {
	
	import excel "Data/Input/Crises Dates Data/RR_crisis_dates_T-Z.xls", sheet("`c'") cellrange(A17:I227) clear
	keep A H
	rename A year
	rename H crisisRR
	gen str30 country = "`c'"
	order year country crisisRR
	tempfile `c'
	save ``c''
}

local i = 1
foreach c in ///
	Taiwan Thailand Tunisia Turkey UK US Uruguay Venezuela Zambia Zimbabwe {

	if `i'==1 {
		use ``c'', clear
	}
	else {
		append using ``c''
	}
	local i = `i' + 1
}
replace country = "USA" if country=="US"

tempfile TZ
save `TZ'

*** combine country data
use `AE'
append using `FM'
append using `MS'
append using `TZ'

egen ccode = group(country)
xtset ccode year
gen first = 1 if crisisRR == 1 & (L.crisisRR==0 | mi(L.crisisRR))
replace crisisRR = 0 if crisisRR==1 & first!=1
drop first

replace country="Russian Federation" if country=="Russia"

gen str3 iso=""
replace iso="DZA" if country=="Algeria"
replace iso="AGO" if country=="Angola"
replace iso="ARG" if country=="Argentina"
replace iso="AUS" if country=="Australia"
replace iso="AUT" if country=="Austria"
replace iso="BEL" if country=="Belgium"
replace iso="BOL" if country=="Bolivia"
replace iso="BRA" if country=="Brazil"
replace iso="CAN" if country=="Canada"
replace iso="CAG" if country=="Central African Republic"
replace iso="CHL" if country=="Chile"
replace iso="CHN" if country=="China"
replace iso="COL" if country=="Colombia"
replace iso="CRI" if country=="Costa Rica"
replace iso="CIV" if country=="Ivory Coast"
replace iso="DNK" if country=="Denmark"
replace iso="DOM" if country=="Dominican Republic"
replace iso="ECU" if country=="Ecuador"
replace iso="EGY" if country=="Egypt"
replace iso="SLV" if country=="El Salvador"
replace iso="FIN" if country=="Finland"
replace iso="FRA" if country=="France"
replace iso="DEU" if country=="Germany"
replace iso="GHA" if country=="Ghana"
replace iso="GRC" if country=="Greece"
replace iso="GTM" if country=="Guatemala"
replace iso="HND" if country=="Honduras"
replace iso="HUN" if country=="Hungary"
replace iso="ISL" if country=="Iceland"
replace iso="IND" if country=="India"
replace iso="IDN" if country=="Indonesia"
replace iso="IRL" if country=="Ireland"
replace iso="ITA" if country=="Italy"
replace iso="JPN" if country=="Japan"
replace iso="KEN" if country=="Kenya"
replace iso="KOR" if country=="Korea"
replace iso="MYS" if country=="Malaysia"
replace iso="MUS" if country=="Mauritius"
replace iso="MEX" if country=="Mexico"
replace iso="MAR" if country=="Morocco"
replace iso="MMR" if country=="Myanmar"
replace iso="NLD" if country=="Netherlands"
replace iso="NZL" if country=="New Zealand"
replace iso="NIC" if country=="Nicaragua"
replace iso="NGA" if country=="Nigeria"
replace iso="NOR" if country=="Norway"
replace iso="PAN" if country=="Panama"
replace iso="PRY" if country=="Paraguay"
replace iso="PER" if country=="Peru"
replace iso="PHL" if country=="Philippines"
replace iso="POL" if country=="Poland"
replace iso="PRT" if country=="Portugal"
replace iso="ROU" if country=="Romania"
replace iso="RUS" if country=="Russian Federation"
replace iso="SGP" if country=="Singapore"
replace iso="ZAF" if country=="South Africa"
replace iso="ESP" if country=="Spain"
replace iso="LKA" if country=="Sri Lanka"
replace iso="SWE" if country=="Sweden"
replace iso="CHE" if country=="Switzerland"
replace iso="TWN" if country=="Taiwan"
replace iso="THA" if country=="Thailand"
replace iso="TUN" if country=="Tunisia"
replace iso="TUR" if country=="Turkey"
replace iso="GBR" if country=="UK"
replace iso="USA" if country=="USA"
replace iso="URY" if country=="Uruguay"
replace iso="VEN" if country=="Venezuela"
replace iso="ZMB" if country=="Zambia"
replace iso="ZWE" if country=="Zimbabwe"

lab var crisisRR "Crises Dates Reinhart & Rogoff (2009)"

drop if iso==""

keep year crisisRR iso
rename crisisRR crisisReinRog

save "$root/Data/Input/Crises Dates Data/ReinhartRogoff_crisis_dates", replace
