
****************************************
*** Process Romer-Romer Crises Dates ***
****************************************

set more off

cd "$root"

foreach c in ///
	Australia Austria Belgium Canada Denmark Finland France Germany Greece ///
	Iceland Ireland Italy Japan Luxembourg Netherlands NewZealand Norway ///
	Portugal Spain Sweden Switzerland Turkey UnitedKingdom UnitedStates {
	
	import excel "Data/Input/Crises Dates Data/RomerRomerCrisesData.xlsx", sheet("New Meas. of Financial Distress") clear firstrow
	keep Date `c'

	rename `c' fin_dist_RR
	drop if mi(fin_dist_RR)
	
	split Date, gen(Date) parse(":")
	destring Date1, gen(year)
	destring Date2, gen(half)
	drop Date*
	
	collapse (max) fin_dist_RR, by(year)
	
	gen country = "`c'"
	
	tsset year 
	
	*** above 0
	gen crisisFinDistRR = 0 if !mi(fin_dist_RR)
	replace crisisFinDistRR = 1 if fin_dist_RR>0 & L.fin_dist_RR == 0
	
	gen crisisFinDistRR_2 = crisisFinDistRR
	replace crisisFinDistRR_2 = 0 if L2.crisisFinDistRR_2 == 1
	
	gen crisisFinDistRR_3 = crisisFinDistRR_2
	replace crisisFinDistRR_3 = 0 if L3.crisisFinDistRR_3 == 1
	
	*** continuous financial distress
	gen crisis_count = 0
	replace crisis_count = 1 if fin_dist_RR>0 & L.fin_dist_RR==0
	replace crisis_count = L.crisis_count + 1 if L.crisis_count>0 & fin_dist_RR>0
	
	gen first_distress = .
	replace first_distress = 1 if fin_dist_RR>0 & L.fin_dist_RR==0
	
	gen last_distress = .
	replace last_distress = 1 if fin_dist_RR>0 & (F.fin_dist_RR==0 | F.fin_dist_RR==.)
	
	gen greater_than_6 = fin_dist_RR > 6
	
	gen crisis_id = year if first_distress == 1
	replace crisis_id = L.crisis_id if L.crisis_id!=. & last_distress!=1 & fin_dist_RR>0
	replace crisis_id = L.crisis_id if last_distress==1 & mi(crisis_id)
	
	*** above 7
	egen min_7up_year = min(year) if fin_dist_RR>6, by(crisis_id)
	
	gen crisisFinDistRR_7up = 0
	replace crisisFinDistRR_7up = 1 if fin_dist_RR>6 & year == min_7up_year & !mi(min_7up_year)

	*** above 7 at least once in crisis - first instance above 0
	egen crisisFinDistRR7up1 = max(greater_than_6), by(crisis_id)
	replace crisisFinDistRR7up1 = 0 if first_distress!=1
	
	tempfile `c'
	save ``c''
}

local i = 1
foreach c in ///
	Australia Austria Belgium Canada Denmark Finland France Germany Greece ///
	Iceland Ireland Italy Japan Luxembourg Netherlands NewZealand Norway ///
	Portugal Spain Sweden Switzerland Turkey UnitedKingdom UnitedStates {
	
	if `i' == 1 {
		use ``c'', clear
	}
	else {
		append using ``c''
	}
	local i = `i' + 1
}

replace country = "UK" if country == "UnitedKingdom"
replace country = "USA" if country == "UnitedStates"
replace country = "New Zealand" if country == "NewZealand"
replace country = "Russian Federation" if country == "Russia"

gen str3 iso=""
replace iso="DZA" if country=="Algeria"
replace iso="AGO" if country=="Angola"
replace iso="ARG" if country=="Argentina"
replace iso="AUS" if country=="Australia"
replace iso="AUT" if country=="Austria"
replace iso="BEL" if country=="Belgium"
replace iso="BOL" if country=="Bolivia"
replace iso="BRA" if country=="Brazil"
replace iso="CAN" if country=="Canada"
replace iso="CAG" if country=="Central African Republic"
replace iso="CHL" if country=="Chile"
replace iso="CHN" if country=="China"
replace iso="COL" if country=="Colombia"
replace iso="CRI" if country=="Costa Rica"
replace iso="CIV" if country=="Ivory Coast"
replace iso="DNK" if country=="Denmark"
replace iso="DOM" if country=="Dominican Republic"
replace iso="ECU" if country=="Ecuador"
replace iso="EGY" if country=="Egypt"
replace iso="SLV" if country=="El Salvador"
replace iso="FIN" if country=="Finland"
replace iso="FRA" if country=="France"
replace iso="DEU" if country=="Germany"
replace iso="GHA" if country=="Ghana"
replace iso="GRC" if country=="Greece"
replace iso="GTM" if country=="Guatemala"
replace iso="HND" if country=="Honduras"
replace iso="HUN" if country=="Hungary"
replace iso="ISL" if country=="Iceland"
replace iso="IND" if country=="India"
replace iso="IDN" if country=="Indonesia"
replace iso="IRL" if country=="Ireland"
replace iso="ITA" if country=="Italy"
replace iso="JPN" if country=="Japan"
replace iso="KEN" if country=="Kenya"
replace iso="KOR" if country=="Korea"
replace iso="MYS" if country=="Malaysia"
replace iso="MUS" if country=="Mauritius"
replace iso="MEX" if country=="Mexico"
replace iso="MAR" if country=="Morocco"
replace iso="MMR" if country=="Myanmar"
replace iso="NLD" if country=="Netherlands"
replace iso="NZL" if country=="New Zealand"
replace iso="NIC" if country=="Nicaragua"
replace iso="NGA" if country=="Nigeria"
replace iso="NOR" if country=="Norway"
replace iso="PAN" if country=="Panama"
replace iso="PRY" if country=="Paraguay"
replace iso="PER" if country=="Peru"
replace iso="PHL" if country=="Philippines"
replace iso="POL" if country=="Poland"
replace iso="PRT" if country=="Portugal"
replace iso="ROU" if country=="Romania"
replace iso="RUS" if country=="Russian Federation"
replace iso="SGP" if country=="Singapore"
replace iso="ZAF" if country=="South Africa"
replace iso="ESP" if country=="Spain"
replace iso="LKA" if country=="Sri Lanka"
replace iso="SWE" if country=="Sweden"
replace iso="CHE" if country=="Switzerland"
replace iso="TWN" if country=="Taiwan"
replace iso="THA" if country=="Thailand"
replace iso="TUN" if country=="Tunisia"
replace iso="TUR" if country=="Turkey"
replace iso="GBR" if country=="UK"
replace iso="USA" if country=="USA"
replace iso="URY" if country=="Uruguay"
replace iso="VEN" if country=="Venezuela"
replace iso="ZMB" if country=="Zambia"
replace iso="ZWE" if country=="Zimbabwe"

drop if iso==""

lab var crisisFinDistRR "Financial Distress Crisis Dates Reinhard & Rogoff"

keep year iso fin_dist_RR crisisFinDistRR* 
order year iso 

save "$root/Data/Input/Crises Dates Data/RomerRomer_fin_distress", replace
