
******************************************
*** Process all income inequality data ***
******************************************

clear all

local WID_pre_tax_national 	= 1
local WID_fiscal 		    = 1

local Sweden_excl_cap 		= 1
local Spain_excl_cap 		= 1
local Belgium_shares 		= 1
local Australia_excl_cap 	= 1
local Canada_shares 		= 1
local Germany_excl_cap 		= 1
local Japan_excl_cap 		= 1
local USA_excl_cap 			= 1
local Norway_excl_cap 		= 1
local France_incl_cap 		= 1

local merge_datasets 		= 1

******************************************
*** Pre-tax national income shares WID ***
******************************************

if `WID_pre_tax_national' == 1 {
	* Note: This is a mix of different units (tax-unit, individual)
	import excel "Data/Input/Inequality Data/Pretax_nat_income_top1.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top1
	keep if year>=1870 & year<=2013

	save "Data/Input/Inequality Data/income_top1.dta", replace

	import excel "Data/Input/Inequality Data/Pretax_nat_income_top10.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top10
	keep if year>=1870 & year<=2013

	save "Data/Input/Inequality Data/income_top10.dta", replace

	import excel "Data/Input/Inequality Data/Pretax_nat_income_top01_equal.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top01_equal
	keep if year>=1870 & year<=2013

	save "Data/Input/Inequality Data/income_top01_equal.dta", replace

	import excel "Data/Input/Inequality Data/Pretax_nat_income_top01_tax_unit.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top01_tax_unit
	keep if year>=1870 & year<=2013

	save "Data/Input/Inequality Data/income_top01_tax_unit.dta", replace

	import excel "Data/Input/Inequality Data/Pretax_nat_income_top01_individual.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top01_ind
	keep if year>=1870 & year<=2013

	merge 1:1 year country using "Data/Input/Inequality Data/income_top01_tax_unit.dta", nogen

	replace income_top01_ind = income_top01_tax_unit if income_top01_ind ==.

	drop income_top01_tax_unit

	merge 1:1 year country using "Data/Input/Inequality Data/income_top01_equal.dta", nogen

	replace income_top01_ind = income_top01_equal if income_top01_ind ==.

	drop income_top01_equal

	rename income_top01_ind income_top01

	save "Data/Input/Inequality Data/income_top01.dta", replace
	
	import excel "Data/Input/Inequality Data/Pretax_nat_income_top001_equal.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top001_equal
	keep if year>=1870 & year<=2013

	save "Data/Input/Inequality Data/income_top001_equal.dta", replace

	import excel "Data/Input/Inequality Data/Pretax_nat_income_top001_tax_unit.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top001_tax_unit
	keep if year>=1870 & year<=2013

	save "Data/Input/Inequality Data/income_top001_tax_unit.dta", replace

	import excel "Data/Input/Inequality Data/Pretax_nat_income_top001_individual.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top001_ind
	keep if year>=1870 & year<=2013

	merge 1:1 year country using "Data/Input/Inequality Data/income_top001_tax_unit.dta", nogen

	replace income_top001_ind = income_top001_tax_unit if income_top001_ind ==.

	drop income_top001_tax_unit

	merge 1:1 year country using "Data/Input/Inequality Data/income_top001_equal.dta", nogen

	replace income_top001_ind = income_top001_equal if income_top001_ind ==.

	drop income_top001_equal

	rename income_top001_ind income_top001

	save "Data/Input/Inequality Data/income_top001.dta", replace
}

********************************
*** Country-specific Changes ***
********************************

if `Sweden_excl_cap' == 1 {

	import excel "Data/Input/Inequality Data/Sweden_shares_excl_Cap.xls", clear sheet("Excl_Cap")

	rename A year
	gen income_top10_swe  = B/100
	gen income_top1_swe   = C/100
	gen income_top01_swe  = D/100 
	gen income_top001_swe = E/100 
	
	drop B C D E

	gen country="Sweden"

	save "Data/Input/Inequality Data/income_top_SWE.dta", replace
}

if `Spain_excl_cap' == 1 {
	import excel "Data/Input/Inequality Data/Spain_shares_excl_Cap.xls", clear sheet("Excl_Cap")

	rename A year
	gen income_top10_esp 	= B/100
	gen income_top1_esp  	= C/100
	gen income_top01_esp 	= D/100
	gen income_top001_esp 	= E/100

	drop B C D E

	gen country="Spain"

	save "Data/Input/Inequality Data/income_top_ESP.dta", replace
}

if `Belgium_shares' == 1 {
	import excel "Data/Input/Inequality Data/Belgium_shares.xls", clear sheet("Shares")

	rename A year
	gen income_top10_bel = B/100
	gen income_top1_bel  = C/100

	drop B C

	gen country="Belgium"

	save "Data/Input/Inequality Data/income_top_BEL.dta", replace
}

if `Australia_excl_cap' == 1 {
	import excel "Data/Input/Inequality Data/Australia_shares_excl_Cap.xls", clear sheet("Excl_Cap")

	gen income_top10_aus 	= B/100
	gen income_top1_aus  	= C/100
	gen income_top01_aus 	= D/100
	gen income_top001_aus 	= E/100

	drop B C D E
	
	gen country="Australia"

	destring A, generate(year)

	drop A

	save "Data/Input/Inequality Data/income_top_AUS.dta", replace
}

if `Canada_shares' == 1 {
	import excel "Data/Input/Inequality Data/Canada_shares.xls", clear sheet("Excl_Cap")

	rename A year
	gen income_top10_can  = B/100
	gen income_top1_can   = C/100
	gen income_top01_can  = D/100
	gen income_top001_can = E/100

	drop B C D E

	save "Data/Input/Inequality Data/income_top_CAN.dta", replace

	import excel "Data/Input/Inequality Data/Canada_shares.xls", clear sheet("Incl_Cap")

	rename A year
	gen income_top10_can_fisc  = B/100
	gen income_top1_can_fisc   = C/100
	gen income_top01_can_fisc  = D/100
	gen income_top001_can_fisc = E/100

	drop B C D E

	merge 1:1 year using "Data/Input/Inequality Data/income_top_CAN.dta", nogen

	gen country="Canada"

	save "Data/Input/Inequality Data/income_top_CAN.dta", replace
}

if `Germany_excl_cap' == 1 {
	import excel "Data/Input/Inequality Data/Germany_shares_excl_Cap.xls", clear sheet("Excl_Cap")

	rename A year
	gen income_top10_deu  = B/100
	gen income_top1_deu   = C/100
	gen income_top01_deu  = D/100 
	gen income_top001_deu = E/100

	drop B C D E

	gen country="Germany"

	save "Data/Input/Inequality Data/income_top_DEU.dta", replace
}

if `Japan_excl_cap' == 1 {
	import excel "Data/Input/Inequality Data/Japan_shares_excl_Cap.xls", clear sheet("Excl_Cap")

	rename A year
	gen income_top1_jpn 	= B/100
	gen income_top01_jpn 	= C/100

	drop B C

	gen country="Japan"

	save "Data/Input/Inequality Data/income_top_JPN.dta", replace
}

if `USA_excl_cap' == 1 {
	import excel "Data/Input/Inequality Data/United_States_shares_excl_Cap.xls", clear sheet("Excl_Cap")

	rename A year
	gen income_top10_usa 	= B/100
	gen income_top1_usa  	= C/100
	gen income_top01_usa 	= D/100
	gen income_top001_usa 	= E/100

	drop B C D E

	gen country="USA"

	save "Data/Input/Inequality Data/income_top_USA.dta", replace
}

if `Norway_excl_cap' == 1 {
	import excel "Data/Input/Inequality Data/Norway_shares_excl_Cap.xls", clear sheet("Excl_Cap")

	rename A year
	gen income_top10_nor 	= B
	gen income_top1_nor  	= C
	gen income_top01_nor 	= D
	
	drop B C D

	gen country="Norway"

	save "Data/Input/Inequality Data/income_top_NOR.dta", replace
}

if `France_incl_cap' == 1 {
	import excel "Data/Input/Inequality Data/France_shares_incl_Cap.xls", clear sheet("Incl_Cap")

	rename A year
	gen income_top10_fra 	= B
	gen income_top1_fra  	= C
	gen income_top01_fra 	= D
	gen income_top001_fra 	= E
	
	drop B C D E

	gen country="France"

	save "Data/Input/Inequality Data/income_top_FRA.dta", replace
}

********************************
*** Fiscal income shares WID ***
********************************

if `WID_fiscal' == 1 {
* Note: I replace the individual series with the tax-unit series, 
* whenever the individual one isn't available

	import excel "Data/Input/Inequality Data/Fiscal_income_top1_tax_unit.xls", clear

	drop B C
	rename A country
	rename D year
	rename E income_top1_fisc_tax
	keep if year>=1870 & year<=2013

	save "Data/Input/Inequality Data/fisc_income_top1_tax_unit.dta", replace

	import excel "Data/Input/Inequality Data/Fiscal_income_top1_individual.xls", clear

	drop B C
	rename A country
	rename D year
	rename E income_top1_fisc_ind
	keep if year>=1870 & year<=2013

	merge 1:1 year country using "Data/Input/Inequality Data/fisc_income_top1_tax_unit.dta", nogen

	replace income_top1_fisc_ind = income_top1_fisc_tax if income_top1_fisc_ind ==.

	drop income_top1_fisc_tax
	rename income_top1_fisc_ind income_top1_fisc

	save "Data/Input/Inequality Data/income_top1_fisc.dta", replace

	import excel "Data/Input/Inequality Data/Fiscal_income_top01_tax_unit.xls", clear

	drop B C
	rename A country
	rename D year
	rename E income_top01_fisc_tax
	keep if year>=1870 & year<=2013

	save "Data/Input/Inequality Data/fisc_income_top01_tax_unit.dta", replace

	import excel "Data/Input/Inequality Data/Fiscal_income_top01_individual.xls", clear

	drop B C
	rename A country
	rename D year
	rename E income_top01_fisc_ind
	keep if year>=1870 & year<=2013

	merge 1:1 year country using "Data/Input/Inequality Data/fisc_income_top01_tax_unit.dta", nogen

	order year country
	sort country year

	replace income_top01_fisc_ind = income_top01_fisc_tax if income_top01_fisc_ind ==.

	drop income_top01_fisc_tax
	rename income_top01_fisc_ind income_top01_fisc

	save "Data/Input/Inequality Data/income_top01_fisc.dta", replace

	import excel "Data/Input/Inequality Data/Fiscal_income_top10_tax_unit.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top10_fisc_tax
	keep if year>=1870 & year<=2013

	save "Data/Input/Inequality Data/fisc_income_top10_tax_unit.dta", replace

	import excel "Data/Input/Inequality Data/Fiscal_income_top10_individual.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top10_fisc_ind
	keep if year>=1870 & year<=2013

	merge 1:1 year country using "Data/Input/Inequality Data/fisc_income_top10_tax_unit.dta", nogen

	order year country
	sort country year

	replace income_top10_fisc_ind = income_top10_fisc_tax if income_top10_fisc_ind ==.

	drop income_top10_fisc_tax
	rename income_top10_fisc_ind income_top10_fisc

	save "Data/Input/Inequality Data/income_top10_fisc.dta", replace
	
	import excel "Data/Input/Inequality Data/Fiscal_income_top001_tax_unit.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top001_fisc_tax
	keep if year>=1870 & year<=2013

	save "Data/Input/Inequality Data/fisc_income_top001_tax_unit.dta", replace

	import excel "Data/Input/Inequality Data/Fiscal_income_top001_individual.xls", clear

	drop B C 
	rename A country
	rename D year
	rename E income_top001_fisc_ind
	keep if year>=1870 & year<=2013

	merge 1:1 year country using "Data/Input/Inequality Data/fisc_income_top001_tax_unit.dta", nogen

	order year country
	sort country year

	replace income_top001_fisc_ind = income_top001_fisc_tax if income_top001_fisc_ind ==.

	drop income_top001_fisc_tax
	rename income_top001_fisc_ind income_top001_fisc

	save "Data/Input/Inequality Data/income_top001_fisc.dta", replace
}

**********************
*** Merge Datasets ***
**********************

if `merge_datasets' == 1 {
	clear
	
	use "Data/Input/Inequality Data/income_top001.dta"
	merge 1:1 year country using "Data/Input/Inequality Data/income_top01.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top1.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top10.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top001_fisc.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top01_fisc.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top1_fisc.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top10_fisc.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top_SWE.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top_ESP.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top_BEL.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top_AUS.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top_CAN.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top_DEU.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top_JPN.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top_USA.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top_NOR.dta", nogen
	merge 1:1 year country using "Data/Input/Inequality Data/income_top_FRA.dta", nogen

	if `Sweden_excl_cap' == 1 {
		replace income_top1 	= income_top1_swe if country=="Sweden"
		replace income_top01 	= income_top01_swe if country=="Sweden"
		replace income_top10 	= income_top10_swe if country=="Sweden"
		replace income_top001 	= income_top001_swe if country=="Sweden"

		drop income_top10_swe income_top1_swe income_top01_swe income_top001_swe
	}
	if `Spain_excl_cap' == 1 {
		replace income_top1 	= income_top1_esp if country=="Spain" & year>=1981
		replace income_top01 	= income_top01_esp if country=="Spain" & year>=1981
		replace income_top10 	= income_top10_esp if country=="Spain" & year>=1981
		replace income_top001 	= income_top001_esp if country=="Spain" & year>=1981
	
	drop income_top10_esp income_top1_esp income_top01_esp income_top001_esp
	} 
	if `Belgium_shares' == 1 {
		replace income_top1 		= income_top1_bel if country=="Belgium"
		replace income_top10 		= income_top10_bel if country=="Belgium"
		replace income_top1_fisc 	= income_top1_bel if country=="Belgium"
		replace income_top10_fisc 	= income_top10_bel if country=="Belgium"

		drop income_top10_bel income_top1_bel
	}
	if `Australia_excl_cap' == 1 {
		replace income_top1 		= income_top1_aus if country=="Australia" & year>=1970
		replace income_top01 		= income_top01_aus if country=="Australia" & year>=1970
		replace income_top001 		= income_top001_aus if country=="Australia" & year>=1970
		replace income_top10 		= income_top10_aus if country=="Australia" & year>=1970

		drop income_top10_aus income_top1_aus income_top01_aus income_top001_aus
	}
	if `Canada_shares' == 1 {
		replace income_top1 		= income_top1_can if country=="Canada"
		replace income_top01 		= income_top01_can if country=="Canada"
		replace income_top001 		= income_top001_can if country=="Canada"
		replace income_top10 		= income_top10_can if country=="Canada"
		replace income_top1_fisc	= income_top1_can_fisc if country=="Canada"
		replace income_top01_fisc 	= income_top01_can_fisc if country=="Canada"
		replace income_top001_fisc 	= income_top001_can_fisc if country=="Canada"
		replace income_top10_fisc 	= income_top10_can_fisc if country=="Canada"

		drop income_top10_c* income_top1_c* income_top01_c* income_top001_c*
	}
	if `Germany_excl_cap' == 1 {
		replace income_top1 		= income_top1_deu if country=="Germany" & 2001<=year & year<=2008
		replace income_top01 		= income_top01_deu if country=="Germany" & 2001<=year & year<=2008
		replace income_top001 		= income_top001_deu if country=="Germany" & 2001<=year & year<=2008
		replace income_top10 		= income_top10_deu if country=="Germany" & 2001<=year & year<=2008

		drop income_top10_deu income_top1_deu income_top01_deu income_top001_deu
	}
	if `Japan_excl_cap' == 1 {
		replace income_top1 		= income_top1_jpn if country=="Japan"
		replace income_top01 		= income_top01_jpn if country=="Japan"

		drop income_top1_jpn income_top01_jpn
	}
	if `USA_excl_cap' == 1 {
		replace income_top1 		= income_top1_usa if country=="USA"
		replace income_top01 		= income_top01_usa if country=="USA"
		replace income_top10 		= income_top10_usa if country=="USA"
		replace income_top001 		= income_top001_usa if country=="USA"

		drop income_top10_usa income_top1_usa income_top01_usa income_top001_usa
	}
	if `Norway_excl_cap' == 1 {
		replace income_top1 		= income_top1_nor if country=="Norway" & year>=2000
		replace income_top01 		= income_top01_nor if country=="Norway" & year>=2000
		replace income_top10 		= income_top10_nor if country=="Norway" & year>=2000

		drop income_top10_nor income_top1_nor income_top01_nor
	}
	if `France_incl_cap' == 1 {
		
		replace income_top1_fisc 	= income_top1_fra  if country=="France"
		replace income_top01_fisc 	= income_top01_fra if country=="France"
		replace income_top001_fisc 	= income_top01_fra if country=="France"
		replace income_top10_fisc	= income_top10_fra if country=="France"

		drop income_top10_fra income_top1_fra income_top01_fra income_top001_fra
	}
	gen iso=""

	replace iso="AUS" if country=="Australia"
	replace iso="BEL" if country=="Belgium"
	replace iso="CAN" if country=="Canada"
	replace iso="CHE" if country=="Switzerland"
	replace iso="DEU" if country=="Germany"
	replace iso="DNK" if country=="Denmark"
	replace iso="ESP" if country=="Spain"
	replace iso="FIN" if country=="Finland"
	replace iso="FRA" if country=="France"
	replace iso="GBR" if country=="United Kingdom"
	replace iso="ITA" if country=="Italy"
	replace iso="JPN" if country=="Japan"
	replace iso="NLD" if country=="Netherlands"
	replace iso="NOR" if country=="Norway"
	replace iso="PRT" if country=="Portugal"
	replace iso="SWE" if country=="Sweden"
	replace iso="USA" if country=="USA"

	order year iso income_top001 income_top001_fisc income_top01 income_top01_fisc income_top1 income_top1_fisc income_top10 income_top10_fisc
	
	sort iso year
	
	drop country
	
	gen check_top_1 		= .
	replace check_top_1 	= 1 if income_top1~=income_top1_fisc
	gen check_top_10 		= .
	replace check_top_10 	= 1 if income_top10~=income_top10_fisc
	gen check_top_01 		= .
	replace check_top_01 	= 1 if income_top01~=income_top01_fisc
	
	drop check*
	
	* Fiscal share series longer than pre-tax national income (both the same)
	replace income_top1  	= income_top1_fisc   if iso=="GBR"
	replace income_top001 	= income_top001_fisc if iso=="GBR"
	replace income_top01  	= income_top01_fisc  if iso=="GBR"
	replace income_top10  	= income_top10_fisc  if iso=="GBR"
	
	* Add three additional years of data from Roine & Waldenstroem
	replace income_top1 = 0.0473751915144372 if year == 1990 & iso == "FIN"
	replace income_top1 = 0.0458312315851503 if year == 1991 & iso == "FIN"
	replace income_top1 = 0.0446935769004125 if year == 1992 & iso == "FIN"
	
	replace income_top1_fisc = 0.0473751915144372 if year == 1990 & iso == "FIN"
	replace income_top1_fisc = 0.0458312315851503 if year == 1991 & iso == "FIN"
	replace income_top1_fisc = 0.0446935769004125 if year == 1992 & iso == "FIN"
	
	save "Data/Input/Inequality Data/inequality.dta", replace
	
}
