*********************************************************************************
**** Historical Patterns of Inequality and Productivity around Financial Crises
**** by Pascal Paul
**** December 2021
**** This File: Data description
*********************************************************************************

set mem 400m
set more off
clear all
clear mata
clear matrix
eststo clear

global root "C:\Users\l1pxp07\Desktop\December 2021"
cd "$root"

//locals for which regressions to run
local process_data		= 1 	// Run data processing programs
global exclude_wars 	= 0 	// Exclude wars from data (set to 0)

local RUN_ALL			= 0 	// Runs all sections of code below

local recession_dates	= 0
local figure1			= 0
local figure2			= 0 	// and Figure 10
local figure3			= 0
local figure4			= 0
local figure5			= 0
local figure9			= 0

if `process_data' == 1 {

	do Data/Programs/PROCESS_ALL_DATA.do
	
}

use "$root/Data/Output/Dataset_description.dta", clear

sort ccode year
xtset ccode year

*********************
** Recession dates **
*********************

if `recession_dates' == 1 | `RUN_ALL' == 1 {

	use "$root/Data/Output/Dataset_description.dta", clear
	sort ccode year
	xtset ccode year 

	levelsof iso, local(isos)

	preserve
	foreach x in crisisJST pk_fin pk_norm {
		foreach i of local isos {
			restore
			preserve
			
			keep if `x'==1 & iso=="`i'"
			keep year
			xpose, clear
			gen iso="`i'"
			order iso
			
			tempfile `x'_`i'
			save ``x'_`i''
		}
	}
	restore

	foreach x in crisisJST pk_fin pk_norm {
		use ``x'_AUS', clear
		foreach i of local isos {
			if "`i'"!="AUS" {
				append using ``x'_`i''
			}
		}
		gen x = "`x'"
		tempfile `x'
		save ``x''
	}

	use `crisisJST', clear
	drop x
	foreach var of varlist _all {
		tostring `var', replace
		replace `var' = "" if `var'=="."
	}
	export delimited "$root/Description/Temp Files/crisis_dates.csv", novar replace
	export excel using "$root/Description/Temp Files/recession_dates.xlsx", sheetmodify first(var) cell("B2") sheet("crisis_dates")

	use `pk_fin', clear
	append using `pk_norm'
	order iso x
	replace x = "F" if x=="pk_fin"
	replace x = "N" if x=="pk_norm"
	foreach var of varlist _all {
		tostring `var', replace
		replace `var' = "" if `var'=="."
	}
	sort iso x
	export delimited "$root/Description/Temp Files/business_cycle_peaks.csv", novar replace
	export excel using "$root/Description/Temp Files/recession_dates.xlsx", sheetmodify first(var) cell("B2") sheet("business_cycle_peaks")
}
*
*
********************************************
** Share of countries in financial crisis **
********************************************

if `figure1' == 1 | `RUN_ALL' == 1 {

	use "$root/Data/Output/Dataset_description.dta", clear
	sort ccode year
	xtset ccode year 
	
	gen crisis3Y = 0
	replace crisis3Y = 1 if crisisJST==1 | L.crisisJST == 1 | F.crisisJST == 1
	
	collapse (sum) crisis3Y, by(year)
	gen percent_in_crisis = crisis3Y/17
	
	keep year percent_in_crisis
	xpose, clear
	
	export delimited using "$root/Description/Temp Files/percent_in_crisis.csv" , delimit(",") replace novar
}
*
*
***************************************
** Dispersion of productivity growth **
***************************************

if `figure2' == 1 | `RUN_ALL' == 1 {

	foreach var in llp ltfp_util {
		
		use "$root/Data/Output/Dataset_description.dta", clear
		
		sort ccode year
		xtset ccode year
		
		gen d`var'_0_10_lag = (`var' - L10.`var')/10

		#delimit ;
		collapse 
			(p10) `var'_p10 = d`var'_0_10_lag
			(p33) `var'_p33 = d`var'_0_10_lag
			(p50) `var'_p50 = d`var'_0_10_lag
			(p66) `var'_p66 = d`var'_0_10_lag
			(p90) `var'_p90 = d`var'_0_10_lag
		, by(year) cw;
		#delimit cr;
		
		foreach v of varlist *_p* {
			replace `v' = `v'*100
		}
		
		tsset year
		tsfill
		
		keep if year>=1900
		
		tempfile `var'
		save ``var''
	}
	
	use `llp', clear
	merge 1:1 year using `ltfp_util', nogen keep(1 3)
	
	drop year
	
	export delimited using "$root/Description/Temp Files/productivity_typical_behavior_10y_TS.csv" , delim(",") replace
	
}
*
*
**************************
** Figure Capital Gains **
**************************

if `figure3' == 1 | `RUN_ALL' == 1 {

	use "$root/Data/Output/Dataset_description.dta", clear
	sort ccode year
	xtset ccode year
	
	keep iso year income_top1 income_top1_fisc
	keep if iso=="ESP" | iso=="USA"
	keep if year>=2000 & year<=2010
	
	replace income_top1 		= income_top1*100
	replace income_top1_fisc 	= income_top1_fisc*100
	
	keep year income_top1 income_top1_fisc
	order year income_top1 income_top1_fisc
	xpose, clear

	export delimited "$root/Description/Temp Files/capital_gains.csv", novar replace
	
}
*
*
************************************
** Income shares for each country **
************************************

if `figure4' == 1 | `RUN_ALL' == 1 {
	
	use "$root/Data/Output/Dataset_description.dta", clear
	
	sort ccode year
	xtset ccode year 
	
	levelsof iso, local(isos)
	
	foreach var in llp ltfp_util {
	
		gen d`var' = `var' - L1.`var'
	
	}
	
	foreach var in income_top1 income_top10 {
		
		replace `var' = 100*`var'
		
	}

	keep iso year income_top1 income_top10 dllp dltfp_util crisisJST
	order iso year income_top1 income_top10 dllp dltfp_util crisisJST
	
	tempfile all_iso
	save `all_iso'
	
	foreach i of local isos {
		use `all_iso', clear
		
		keep if iso=="`i'"
		tsset year
		tsfill
		keep year income_top1 income_top10 dllp dltfp_util crisisJST
		
		replace dllp = dllp*100
		replace dltfp_util = dltfp_util*100
		
		xpose, clear
		export delimited "$root/Description/Temp Files/`i'.csv", novar replace
	}
}
*
*
**********************************************
** Typical behavior around financial crises **
**********************************************

if `figure5' == 1 | `RUN_ALL' == 1 {

	local avariables  lloansr income_top1 ltfp_util income_top10 llp ltfp
	local avariables1 income_top1 income_top10 ltfp ltfp_util llp
	
	graph drop _all
	
	foreach var of local avariables {
	
		use "$root/Data/Output/Dataset_description.dta", clear
		
		sort  ccode year
		xtset ccode year
		
		** create lagged and forward variables
		foreach i of numlist 0/7 {
			gen L`i'`var' = L`i'.`var' if crisisJST==1
		}
		foreach j of numlist 0/6 {
			gen F`j'`var' = F`j'.`var' if crisisJST==1
		}
		
		* t = -7 to -1
		foreach i of numlist 1/6 {
			local i1 = `i'
			local j1 = `i1' + 1
			gen dL`i'`var' = 100*((L`i1'`var' - L`j1'`var'))
		}
		* t = 1 to 3
		foreach j of numlist 1/3 {
			local j1 = `j'
			local i1 = `j1' - 1
			gen dF`j'`var' = 100*((F`j1'`var' - F`i1'`var'))
		}
		* t = 0
		gen dCrisis`var' = 100*((F0`var' - L1`var'))
		
		*drop L*`var' F*`var'
		
		#delimit ;
		order dL6`var' dL5`var' dL4`var' dL3`var' dL2`var' dL1`var'
				dCrisis`var'
				dF1`var' dF2`var' dF3`var' , last;
		#delimit cr;
		
		*** compute percentiles for each variable at each year before/after/during fin crisis
		** save in matrices
		foreach n in dL6 dL5 dL4 dL3 dL2 dL1 dCrisis dF1 dF2 dF3 {
			_pctile `n'`var' if crisisJST==1, p(5 10 25 33 50 66 75 90 95)
			matrix def `n'`var' = (r(r1) \ r(r2) \ r(r3) \ r(r4) \ r(r5) \ r(r6) \ r(r7) \ r(r8) \ r(r9) )
		}
		
		*** join matrices
		matrix `var' = dL6`var'
		foreach n in dL5 dL4 dL3 dL2 dL1 dCrisis dF1 dF2 dF3 {
			matrix `var' = (`var',`n'`var')
		}
		
		drop _all 
		
		*** display matrices
		svmat `var' 
		
		*** transpose data
		xpose, clear
		
		rename v1 p5
		rename v2 p10
		rename v3 p25
		rename v4 p33
		rename v5 p50
		rename v6 p66
		rename v7 p75
		rename v8 p90
		rename v9 p95
		
		gen t = -6 if _n==1
		replace t = t[_n-1]+1 if _n!=1
		order t
		
		tsset t
		
		export delimited using "$root/Description/Temp Files/d`var'.csv" , delim(",") replace
	}

	foreach p in 33 50 66 {
		foreach var in `avariables' {
			import delimited using "$root/Description/Temp Files/d`var'.csv" , delim(",") clear
			keep p`p'
			xpose, clear
			tempfile `var'
			save ``var''
		}
		
		use `lloansr', clear
		foreach var in `avariables1' {
			append using ``var''
		}
		
		export delimited using "$root/Description/Temp Files/p`p'.csv" , delim(",") novar replace
		
	}
}
*
*
***********************************************
** Comparison of Fernald's util-adj and Imbs **
***********************************************

if `figure9' == 1 | `RUN_ALL' == 1 {

	use "$root/Data/Output/Dataset_description.dta", clear
	sort ccode year
	xtset ccode year

	keep iso year dutil dlutil dlutil_pred
	keep if iso=="USA" & year>=1961

	replace dlutil = dlutil*100
	replace dlutil_pred = dlutil_pred*100

	keep year dutil dlutil_pred dlutil
	order year dutil dlutil_pred dlutil
	xpose, clear

	export delimited "$root/Description/Temp Files/utilization.csv", novar replace
	
}
