*********************************************************************************
**** Historical Patterns of Inequality and Productivity around Financial Crises
**** by Pascal Paul
**** December 2021
**** This File: Analysis of Prediction Part
*********************************************************************************

set mem 400m
set more off
clear all
clear mata
clear matrix
eststo clear

global root "C:\Users\l1pxp07\Desktop\December 2021"
cd "$root"

//locals for which regressions to run
*** Process data
local process_data					= 0 // Run data processing programs
global exclude_wars 				= 1 // Exclude wars from data (set to 1)

*** Regressions and tables
local RUN_ALL						= 1 // Runs all sections of code

local table_1and3					= 0 // Main regression tables
local table_2and4					= 0 // Adding sets of controls to income top1 and LP
local table_B1_B5					= 0 // Robustness checks: modifications to baseline regressions
local table_B2_B6					= 0 // Robustness checks: alternative crisis dates
local table_B3						= 0 // Wealth-to-income ratio
local table_B4						= 0 // Robustness checks: productivity and credit, post-WWII, restricted samples
local table_B7						= 0 // Horse race: credit, income top1, and LP

*** Data for AUROC figures
local figures_B1_B3					= 0 // Data for AUROC figures

if `process_data' == 1 {
	do "$root/Data/Programs/PROCESS_ALL_DATA.do"
}

include "$root/Prediction/prediction_regression_estimation.do"

use "$root/Data/Output/Dataset_prediction.dta", clear

sort ccode year
xtset ccode year

eststo clear

************************************
******** Prediction tables *********
************************************

cd "$root/Prediction"

***********************************************
** Regressions and tables - main regressions **
***********************************************

if `table_1and3' == 1 | `RUN_ALL' == 1 {
	preserve
	
	eststo clear
	
	foreach var in lloansr ltfp_util llp income_top1 income_top10 {
		
		gen d`var'_1_5lag = L1.`var' - L5.`var'
		
	}
	
	*** Create same-sample indicators
	cap drop *_sample
	* inequality
	logit crisisJST dlloansr_1_5lag dincome_top1_1_5lag dincome_top10_1_5lag ccode*, vce(robust)
	gen ineq_sample = e(sample)
	* productivity
	logit crisisJST dlloansr_1_5lag dltfp_util_1_5lag dllp_1_5lag ccode*, vce(robust)
	gen prod_sample = e(sample)
	
	*** Individual vars - credit, productivity, inequality
	local vars_prod dlloansr dltfp_util dllp
	local vars_ineq dlloansr dincome_top1 dincome_top10
	
	foreach s in prod ineq {
		foreach var of local vars_`s' {
			sort ccode year
			xtset ccode year 
			
			local name 			`var'_`s'
			local model			logit
			local depvar 		crisisJST
			local var1	 		`var'_1_5lag
			local var2	 		
			local var3	 		
			local var4	 		
			local var5	 		
			local var6	 		
			local var7	 		
			local CFE			ccode*
			local subset		
			local restricted	`s'
			local controls		
			prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
		}
	}

	*** Credit + inequality or productivity
	local vars_prod dltfp_util dllp
	local vars_ineq dincome_top1 dincome_top10
	
	foreach s in prod ineq {
		foreach var of local vars_`s' {
			sort ccode year
			xtset ccode year 
			
			local name 			cred_`var'
			local model			logit
			local depvar 		crisisJST
			local var1	 		dlloansr_1_5lag
			local var2	 		`var'_1_5lag
			local var3	 		
			local var4	 		
			local var5	 		
			local var6	 		
			local var7	 		
			local CFE			ccode*
			local subset		
			local restricted	`s'
			local controls		
			prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
		}
	}
	
	sort ccode year
	xtset ccode year 
	
	local name 			cred_income_top1_top10
	local model			logit
	local depvar 		crisisJST
	local var1	 		dlloansr_1_5lag
	local var2	 		dincome_top1_1_5lag
	local var3	 		dincome_top10_1_5lag
	local var4	 		
	local var5	 		
	local var6	 		
	local var7	 		
	local CFE			ccode*
	local subset		
	local restricted	ineq
	local controls		
	prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"

	#delimit ;
	*** Credit and Inequality;
	esttab dlloansr_ineq dincome_top1_ineq dincome_top10_ineq cred_dincome_top1 cred_dincome_top10 cred_income_top1_top10 using "Tables/Credit_and_Inequality_Restricted.tex", replace se 
	nocons nogaps eqlabels(none) label nonumbers nomtitles
	drop(d* ccode* *ccode _cons)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(space
		  dlloansr_coef
		  dlloansr_coef_se
		  mfxdlloansr
		  space
		  dincome_top1_coef
		  dincome_top1_coef_se
		  mfxdincome_top1
		  space
		  dincome_top10_coef
		  dincome_top10_coef_se
		  mfxdincome_top10
		  space
		  hline
		  Ncrisis
		  Num
		  groups
		  cfe
		  pFcountry
		  R_2
		  area1 
		  seroc 
		  space
		  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3)
	l(" "
	  "$\Delta_4 \mathrm{log(Credit)_{t-1}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{Income \ Share \ 1 \%_{t-1}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{Income \ Share \ 10 \%_{t-1}} $"
	  " "
	  " "
	  " "
	  "\hline"
	  "Number of crises"
	  "Observations" 
	  "Countries"
	  "Country FE"
	  "\textcolor{white}{***}\textit{p-value}" 
	  "Pseudo R$^2$"
	  "AUROC" 
	  " "
	  "\"
	  )) ;
	  
	*** credit and productivity;
	esttab dlloansr_prod dltfp_util_prod dllp_prod cred_dltfp_util cred_dllp using "Tables/Credit_and_Productivity_Restricted.tex", replace se 
	nocons nogaps eqlabels(none) label nonumbers nomtitles
	drop(d* ccode* *ccode _cons)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(space
		  dlloansr_coef
		  dlloansr_coef_se
		  mfxdlloansr
		  space
		  dltfp_util_coef
		  dltfp_util_coef_se
		  mfxdltfp_util
		  space
		  dllp_coef
		  dllp_coef_se
		  mfxdllp
		  space
		  hline
		  Ncrisis
		  Num
		  groups
		  cfe
		  pFcountry
		  R_2
		  area1 
		  seroc
		  space
		  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3) 
	l(" "
	  "$\Delta_4 \mathrm{log(Credit)_{t-1}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{log(TFP)_{t-1}^{util.-adj.}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{log(LP)_{t-1}} $"
	  " "
	  " "
	  " "
	  "\hline"
	  "Number of crises"
	  "Observations" 
	  "Countries"
	  "Country FE"
	  "\textcolor{white}{***}\textit{p-value}" 
	  "Pseudo R$^2$"
	  "AUROC" 
	  " "
	  "\"
	  )) ;
	#delimit cr;
	
	eststo clear
	
	restore
}
*
**********************************************
** Regressions and tables - adding controls **
**********************************************

if `table_2and4' == 1 | `RUN_ALL' == 1 {
	
	preserve
	
	foreach var in lloansr ltfp_util llp income_top1 income_top10 iy lpc stir ltrate cay debtgdp lhpr lrstocks lGl_rGDP lrgdp {
		
		gen d`var'_1_5lag = L1.`var' - L5.`var'
		
	}
	
	eststo clear
	
	local vars_prod dllp dltfp_util
	local vars_ineq dincome_top1 dincome_top10
	
	local c1_ineq dlloansr dlpc diy dstir dltrate dcay ddebtgdp
	local c2_ineq dlloansr dlpc diy dstir dltrate dcay ddebtgdp dlrgdp dlGl_rGDP 
	local c3_ineq dlloansr dlpc diy dstir dltrate dcay ddebtgdp dlrgdp dlGl_rGDP dlhpr dlrstocks
	
	local c1_prod dlloansr dlpc diy dstir dltrate dcay ddebtgdp 
	local c2_prod dlloansr dlpc diy dstir dltrate dcay ddebtgdp dlhpr dlrstocks
	local c3_prod dlloansr dlpc diy dstir dltrate dcay ddebtgdp dlhpr dlrstocks dincome_top1
	
	foreach j in ineq prod {
		foreach i in 1 2 3 {
			local cont`i'_`j' ""
			foreach c of local c`i'_`j' {
				local cont`i'_`j' = "`cont`i'_`j'' `c'_1_5lag"
			}
			di as error "`cont`i'_`j''"
		}
	}
	
	foreach s in prod ineq {
		foreach var of local vars_`s' {
			foreach c in 1 2 3 {
				sort ccode year
				xtset ccode year 
				
				local name 			`var'_cont`c'
				local model			logit
				local depvar 		crisisJST
				local var1	 		`var'_1_5lag
				local var2	 		
				local var3	 		
				local var4	 		
				local var5	 		
				local var6	 		
				local var7	 		
				local CFE			ccode*
				local subset		
				local restricted	
				local controls		"`cont`c'_`s''"
				prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
			}
		}
	}

	*** Inputting results into latex tables
	#delimit ;
	*** income share top 1%;
	esttab dincome_top1_cont1 dincome_top1_cont2 dincome_top1_cont3 using "Tables/Top1_with_controls.tex", replace se 
	nocons nogaps eqlabels(none) label nonumbers nomtitles
	drop(d* ccode* *ccode _cons)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(space
		  dincome_top1_coef
		  dincome_top1_coef_se
		  mfxdincome_top1
		  space
		  hline
		  controls
		  gdpcont
		  stkhpcont
		  space
		  hline
		  Ncrisis
		  Num
		  groups
		  cfe
		  pFcountry
		  R_2
		  area1 
		  seroc
		  space
		  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3) 
	l(" "
	  "$\Delta_4 \mathrm{Income \ Share \ 1 \%_{t-1}} $"
	  " "
	  " "
	  " "
	  "\hline"
	  "Set of controls"
	  "GDP \& Global GDP"
	  "Stock \& House Prices"
	  " "
	  "\hline"
	  "Number of crises"
	  "Observations" 
	  "Countries"
	  "Country FE"
	  "\textcolor{white}{***}\textit{p-value}" 
	  "Pseudo R$^2$"
	  "AUROC" 
	  " "
	  "\"
	  )) ;
	*** Labor productivity;
	esttab dllp_cont1 dllp_cont2 dllp_cont3 using "Tables/LP_with_controls.tex", replace se 
	nocons nogaps eqlabels(none) label nonumbers nomtitles
	drop(d* ccode* *ccode _cons)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(space
		  dllp_coef
		  dllp_coef_se
		  mfxdllp
		  space
		  hline
		  controls
		  stkhpcont
		  incT1cont
		  space
		  hline
		  Ncrisis
		  Num
		  groups
		  cfe
		  pFcountry
		  R_2
		  area1 
		  seroc
		  space
		  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3) 
	l(" "
	  "$\Delta_4 \mathrm{log(LP)_{t-1}} $"
	  " "
	  " "
	  " "
	  "\hline"
	  "Set of controls"
	  "Stock \& House Prices"
	  "Income Share 1\%"
	  " "
	  "\hline"
	  "Number of crises"
	  "Observations" 
	  "Countries"
	  "Country FE"
	  "\textcolor{white}{***}\textit{p-value}" 
	  "Pseudo R$^2$"
	  "AUROC" 
	  " "
	  "\"
	  )) ;
	#delimit cr;
	
	eststo clear
	
	restore
}
*
********************************************************************
** Regressions and tables - Robustness: modifications to baseline **
********************************************************************

if `table_B1_B5' == 1 | `RUN_ALL' == 1 {

	preserve
	
	gen era 			= "PostWW2" if year>1945
	replace era 		= "PreWW2" if year<=1945
	gen gtdep 			= 0
	replace gtdep 		= 1 if year>1929 & year<1940
	gen gr 				= 0
	replace gr 			= 1 if year>=2007
	gen X 				= exp(lrgdp)/exp(ltfp)
	gen lX 				= log(X)
	
	foreach var in income_top1 income_top10 llp lloansr lX {
		
		gen d`var'_1_5lag = L1.`var' - L5.`var'
		
	}

	eststo clear

	sort ccode year
	xtset ccode year
	
	* With credit - unrestricted samples - LP, income top1, log income top1
	foreach var in dllp dincome_top1 {
		local name 			`var'_cr
		local model			logit
		local depvar 		crisisJST
		local var1	 		dlloansr_1_5lag
		local var2	 		`var'_1_5lag
		local var3	 		
		local var4	 		
		local var5	 		
		local var6	 		
		local var7	 		
		local CFE			ccode*
		local subset		
		local restricted	
		local controls		
		prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
	}
	
	* Subsamples
	foreach sub in PrWW2 PoWW2 xGDGR {
		foreach var in dllp dincome_top1 {
			sort ccode year
			xtset ccode year 
			
			local name 			`var'_cr_`sub'
			local model			logit
			local depvar 		crisisJST
			local var1	 		dlloansr_1_5lag
			local var2	 		`var'_1_5lag
			local var3	 		
			local var4	 		
			local var5	 		
			local var6	 		
			local var7	 		
			local CFE			ccode*
			local subset		`sub'
			local restricted	
			local controls		
			prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
		}
	}

	* Financial and Nonfinancial Recessions
	foreach dep in pk_fin pk_norm {
		foreach var in dllp dincome_top1 {
			local name 			`var'_cr_`dep'
			local model			logit
			local depvar 		`dep'
			local var1	 		dlloansr_1_5lag
			local var2	 		`var'_1_5lag
			local var3	 		
			local var4	 		
			local var5	 		
			local var6	 		
			local var7	 		
			local CFE			ccode*
			local subset		
			local restricted	
			local controls		
			prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
		}
	}
	
	* Input factors and credit
	local name 			input_factor_cr
	local model			logit
	local depvar 		crisisJST
	local var1	 		dlloansr_1_5lag
	local var2	 		dlX_1_5lag
	local var3	 		
	local var4	 		
	local var5	 		
	local var6	 		
	local var7	 		
	local CFE			ccode*
	local subset		
	local restricted	
	local controls		
	prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
	
	******************************************
	*** Inputting results into latex tables  *
	******************************************
	
	#delimit ;
	*** Income top 1 robustness;
	*** robustness table - add headers;
	esttab dincome_top1_cr dincome_top1_cr_PrWW2 dincome_top1_cr_PoWW2 dincome_top1_cr_xGDGR dincome_top1_cr_pk_fin dincome_top1_cr_pk_norm using "Tables/Top1_Robustness.tex", replace se
	mtitle("\textcolor{white}{-}\thead{(1) \\ Baseline}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(2) \\ Pre-WWII}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(3) \\ Post-WWII}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(4) \\ Great Recession \\ \& Depression}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(5) \\ Financial \\ Recessions}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(6) \\ Nonfinancial \\ Recessions}\textcolor{white}{***}"
		   )
	nocons nogaps eqlabels(none) label nonumbers
	drop(d* ccode* *ccode _cons)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(space
		  dlloansr_coef
		  dlloansr_coef_se
		  mfxdlloansr
		  space
		  dincome_top1_coef
		  dincome_top1_coef_se
		  mfxdincome_top1
		  space
		  hline
		  Ncrisis
		  Num
		  groups
		  cfe
		  pFcountry
		  R_2
		  area1 
		  seroc
		  space
		  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3) 
	l(" "
	  "$\Delta_4 \mathrm{log(Credit)_{t-1}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{Income \ Share \ 1 \%_{t-1}} $"
	  " "
	  " "
	  " "
	  "\hline"
	  "Number of crises / recessions"
	  "Observations" 
	  "Countries"
	  "Country FE"
	  "\textcolor{white}{***}\textit{p-value}" 
	  "Pseudo R$^2$"
	  "AUROC" 
	  " "
	  "\"
	  )) ;
	
	*** labor productivity robustness;
	*** robustness table 1 - add headers;
	esttab dllp_cr dllp_cr_PrWW2 dllp_cr_PoWW2 dllp_cr_pk_fin dllp_cr_pk_norm input_factor_cr using "Tables/LP_Robustness.tex", replace se
	mtitle("\textcolor{white}{-}\thead{(1) \\ Baseline}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(2) \\ Pre-WWII}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(3) \\ Post-WWII}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(4) \\ Financial \\ Recessions}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(5) \\ Nonfinancial \\ Recessions}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(6) \\ Input \\ Factors}\textcolor{white}{***}"
		   )
	nocons nogaps eqlabels(none) label nonumbers 
	drop(d* ccode* *ccode _cons)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(space
		  dlloansr_coef
		  dlloansr_coef_se
		  mfxdlloansr
		  space
		  dllp_coef
		  dllp_coef_se
		  mfxdllp
		  space
		  dlX_coef
		  dlX_coef_se
		  mfxdlX
		  space
		  hline
		  Ncrisis
		  Num
		  groups
		  cfe
		  pFcountry
		  R_2
		  area1 
		  seroc
		  space
		  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3) 
	l(" "
	  "$\Delta_4 \mathrm{log(Credit)_{t-1}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{log(LP)_{t-1}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{log(Input \ Factors)_{t-1}} $"
	  " "
	  " "
	  " "
	  "\hline"
	  "Number of crises / recessions"
	  "Observations" 
	  "Countries"
	  "Country FE"
	  "\textcolor{white}{***}\textit{p-value}" 
	  "Pseudo R$^2$"
	  "AUROC" 
	  " "
	  "\"
	  )) ;
	#delimit cr
	
	eststo clear
	
	restore
}
*
*******************************************************************
** Regressions and tables - Robustness: alternative crises dates **
*******************************************************************

if `table_B2_B6' == 1 | `RUN_ALL' == 1 {
	
	preserve 
	
		foreach var in lloansr llp income_top1 {
		
			gen d`var'_1_5lag = L1.`var' - L5.`var'
			
		}
		
	foreach crisis in ReinRog LV Bordo FinDistRR {
		
		local dlloansr_short "cred"
		local dllp_short "LP"
		local dincome_top1_short "Top1"
		
		replace crisisJST = crisis`crisis'
		
		*** Credit + one other
		local vars_prod dllp
		local vars_ineq dincome_top1

		foreach s in prod ineq {
			foreach var of local vars_`s' {
				sort ccode year
				xtset ccode year 

				local name 			``var'_short'_cr_`crisis'
				local model			logit
				local depvar 		crisisJST
				local var1	 		dlloansr_1_5lag
				local var2	 		`var'_1_5lag
				local var3	 		
				local var4	 		
				local var5	 		
				local var6	 		
				local var7	 		
				local CFE			ccode*
				local subset		
				local restricted	
				local controls		
				prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
			}
		}
	
	}

		*** Inputting results into latex tables
		#delimit ;
		*** Credit and Inequality;
		esttab Top1_cr_ReinRog Top1_cr_LV Top1_cr_Bordo Top1_cr_FinDistRR using "Tables/Credit_and_Inequality_Dates.tex", replace se
		mtitle("\textcolor{white}{-}\thead{(1) \\ Reinhart-Rogoff}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(2) \\ Bordo-et-al.}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(3) \\ Laeven-Valencia}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(4) \\ Romer-Romer}\textcolor{white}{***}"
		   )
		nocons nogaps eqlabels(none) label nonumbers 
		drop(d* ccode* *ccode _cons)
		star(* 0.1 ** 0.05 *** 0.01)
		stats(space
			  dlloansr_coef
			  dlloansr_coef_se
			  mfxdlloansr
			  space
			  dincome_top1_coef
			  dincome_top1_coef_se
			  mfxdincome_top1
			  space
			  hline
			  Ncrisis
			  Num
			  groups
			  cfe
			  pFcountry
			  R_2
			  area1 
			  seroc 
			  space
			  , 
			  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
				 fmt(3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3)
		l(" "
		  "$\Delta_4 \mathrm{log(Credit)_{t-1}} $"
		  " "
		  " "
		  " "
		  "$\Delta_4 \mathrm{Income \ Share \ 1 \%_{t-1}} $"
		  " "
		  " "
		  " "
		  "\hline"
		  "Number of crises"
		  "Observations" 
		  "Countries"
		  "Country FE"
		  "\textcolor{white}{***}\textit{p-value}" 
		  "Pseudo R$^2$"
		  "AUROC" 
		  " "
		  "\"
		  )) ;
		  
		*** credit and productivity;
		esttab LP_cr_ReinRog LP_cr_LV LP_cr_Bordo LP_cr_FinDistRR using "Tables/Credit_and_Productivity_Dates.tex", replace se
		mtitle("\textcolor{white}{-}\thead{(1) \\ Reinhart-Rogoff}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(2) \\ Bordo-et-al.}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(3) \\ Laeven-Valencia}\textcolor{white}{***}"
		   "\textcolor{white}{-}\thead{(4) \\ Romer-Romer}\textcolor{white}{***}"
		   )
		nocons nogaps eqlabels(none) label nonumbers
		drop(d* ccode* *ccode _cons)
		star(* 0.1 ** 0.05 *** 0.01)
		stats(space
			  dlloansr_coef
			  dlloansr_coef_se
			  mfxdlloansr
			  space
			  dllp_coef
			  dllp_coef_se
			  mfxdllp
			  space
			  hline
			  Ncrisis
			  Num
			  groups
			  cfe
			  pFcountry
			  R_2
			  area1 
			  seroc 
			  space
			  , 
			  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
				 fmt(3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3) 
		l(" "
		  "$\Delta_4 \mathrm{log(Credit)_{t-1}} $"
		  " "
		  " "
		  " "
		  "$\Delta_4 \mathrm{log(LP)_{t-1}} $"
		  " "
		  " "
		  " "
		  "\hline"
		  "Number of crises"
		  "Observations" 
		  "Countries"
		  "Country FE"
		  "\textcolor{white}{***}\textit{p-value}" 
		  "Pseudo R$^2$"
		  "AUROC" 
		  " "
		  "\"
		  )) ;
		#delimit cr;
		
		eststo clear
	restore
}
*
****************************************************************************************
** Regressions and tables - Robustness: Wealth-to-income ratio and house/stock prices **
****************************************************************************************

if `table_B3' == 1 | `RUN_ALL' == 1 {
	preserve
	
	eststo clear
	
	foreach var in lloansr lrstocks wealth_income lhpr {
	
		gen d`var'_1_5lag = L1.`var' - L5.`var'
		
	}
		
	cap drop *_sample
	logit crisisJST dwealth_income_1_5lag dlhpr_1_5lag dlrstocks_1_5lag ccode*,  vce(robust)
	gen wealth_income_sample = e(sample)

	*** Wealth-to-income ratio only
	sort ccode year
	xtset ccode year

	local name 			WI
	local model			logit
	local depvar 		crisisJST
	local var1	 		dwealth_income_1_5lag
	local var2	 		
	local var3	 		
	local var4	 		
	local var5	 		
	local var6	 		
	local var7	 		
	local CFE			ccode*
	local subset		
	local restricted	WI
	local controls		
	prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
	
	
	*** Wealth-to-income ratio + house prices + stock prices
	local name 			WI_hp_sp
	local model			logit
	local depvar 		crisisJST
	local var1	 		dwealth_income_1_5lag
	local var2	 		dlhpr_1_5lag
	local var3	 		dlrstocks_1_5lag
	local var4	 		
	local var5	 		
	local var6	 		
	local var7	 		
	local CFE			ccode*
	local subset		
	local restricted	WI
	local controls		
	prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
		
	graph close _all
	graph drop _all

	*** Exporting to latex

	#delimit ;
	*** income share + house prices + stocks;
	esttab WI WI_hp_sp using "Tables/$today/WealthIncomeRatio_House_and_Stocks_Prices.tex", replace se
	nocons nogaps eqlabels(none) label nonumbers nomtitles
	drop(d* ccode* *ccode _cons)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(space
		  dwealth_income_coef
		  dwealth_income_coef_se
		  mfxdwealth_income
		  space
		  dlhpr_coef
		  dlhpr_coef_se
		  mfxdlhpr
		  space
		  dlrstocks_coef
		  dlrstocks_coef_se
		  mfxdlrstocks
		  space
		  hline
		  Ncrisis
		  Num
		  groups
		  cfe
		  pFcountry
		  R_2
		  area1 
		  seroc
		  space
		  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3) 
	l(" "
	  "$\Delta_4 \mathrm{Wealth\text{-}to\text{-}income \ Ratio_{t-1}}$"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{log(House \ Prices)_{t-1}}$"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{log(Stock \ Prices)_{t-1}}$"
	  " "
	  " "
	  " "
	  "\hline"
	  "Number of crises"
	  "Observations" 
	  "Countries"
	  "Country FE"
	  "\textcolor{white}{***}\textit{p-value}" 
	  "Pseudo R$^2$"
	  "AUROC" 
	  " "
	  "\"
	  )) ;
	#delimit cr
	
	eststo clear
	
	restore
}
*
*****************************************************************************************
** Regressions and tables - Robustness: Productivity and credit, post-WWII, restricted **
*****************************************************************************************

if `table_B4' == 1 | `RUN_ALL' == 1 {
	preserve
	
	eststo clear
	
	cap drop *_sample
	
	foreach var in lloansr ltfp_util llp {
	
		gen d`var'_1_5lag = L1.`var' - L5.`var'
		
	}
	
	logit crisisJST dlloansr_1_5lag dltfp_util_1_5lag dllp_1_5lag ccode*,  vce(robust)
	gen prod_sample = e(sample)
	
	gen era 			= "PostWW2" if year>1945
	replace era 		= "PreWW2"  if year<=1945
	
	*** CFE-only model
	local name 			CFEonly_PoWW2
	local model			logit
	local depvar 		crisisJST
	local var1	 		
	local var2	 		
	local var3	 		
	local var4	 		
	local var5	 		
	local var6	 		
	local var7	 		
	local CFE			ccode*
	local subset		PoWW2
	local restricted	prod
	local controls		
	prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
	
	* Individual vars
	foreach var in dlloansr dltfp_util dllp {
		sort ccode year
		xtset ccode year
			
		local name 			`var'_PoWW2
		local model			logit
		local depvar 		crisisJST
		local var1	 		`var'_1_5lag
		local var2	 		
		local var3	 		
		local var4	 		
		local var5	 		
		local var6	 		
		local var7	 		
		local CFE			ccode*
		local subset		PoWW2
		local restricted	prod
		local controls		
		prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
	}
			
	* credit + tfp_util or lp
	foreach var in dltfp_util dllp {
		sort ccode year
		xtset ccode year
			
		local name 			`var'_cr_PoWW2
		local model			logit
		local depvar 		crisisJST
		local var1	 		dlloansr_1_5lag
		local var2	 		`var'_1_5lag
		local var3	 		
		local var4	 		
		local var5	 		
		local var6	 		
		local var7	 		
		local CFE			ccode*
		local subset		PoWW2
		local restricted	prod
		local controls		
		prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
	}

	*** inputting results into latex tables
	#delimit ;
	*** credit and productivity - CFE-only model included;
	esttab CFEonly_PoWW2 dlloansr_PoWW2 dltfp_util_PoWW2 dllp_PoWW2 dltfp_util_cr_PoWW2 dllp_cr_PoWW2 using "Tables/$today/Credit_and_Productivity_postWW2_Restricted.tex", replace se 
	nocons nogaps eqlabels(none) label nonumbers nomtitles
	drop(d* ccode* *ccode _cons)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(space
		  dlloansr_coef
		  dlloansr_coef_se
		  mfxdlloansr
		  space
		  dltfp_util_coef
		  dltfp_util_coef_se
		  mfxdltfp_util
		  space
		  dllp_coef
		  dllp_coef_se
		  mfxdllp
		  space
		  hline
		  Ncrisis
		  Num
		  groups
		  cfe
		  pFcountry
		  R_2
		  area1 
		  seroc
		  space
		  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3) 
	l(" "
	  "$\Delta_4 \mathrm{log(Credit)_{t-1}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{log(TFP)_{t-1}^{util.-adj.}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{log(LP)_{t-1}} $"
	  " "
	  " "
	  " "
	  "\hline"
	  "Number of crises"
	  "Observations" 
	  "Countries"
	  "Country FE"
	  "\textcolor{white}{***}\textit{p-value}" 
	  "Pseudo R$^2$"
	  "AUROC" 
	  " "
	  "\"
	  )) ;
	#delimit cr
	
	eststo clear
	
	restore
}
*
*****************************************
** Regressions and tables - Horse race **
*****************************************

if `table_B7' == 1 | `RUN_ALL' == 1 {
	preserve 
	
	eststo clear

	cap drop *_sample
	
	foreach var in lloansr ltfp_util llp income_top1 {
	
		gen d`var'_1_5lag = L1.`var' - L5.`var'
		
	}

	*** Create same-sample indicators
	logit crisisJST dlloansr_1_5lag dincome_top1_1_5lag dllp_1_5lag , vce(robust)
	gen horse_sample = e(sample)

	sort ccode year
	xtset ccode year 

	foreach var in dlloansr dincome_top1 dllp {
		local name 			`var'
		local model			logit
		local depvar 		crisisJST
		local var1	 		`var'_1_5lag
		local var2	 		
		local var3	 		
		local var4	 		
		local var5	 		
		local var6	 		
		local var7	 		
		local CFE			
		local subset		
		local restricted	horse
		local controls		
		prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
	}

	foreach var in dincome_top1 dllp {
		local name 			`var'_cr
		local model			logit
		local depvar 		crisisJST
		local var1	 		dlloansr_1_5lag
		local var2	 		`var'_1_5lag
		local var3	 		
		local var4	 		
		local var5	 		
		local var6	 		
		local var7	 		
		local CFE			
		local subset		
		local restricted	horse
		local controls		
		prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
	}

	local name 			cr_top1_LP
	local model			logit
	local depvar 		crisisJST
	local var1	 		dlloansr_1_5lag
	local var2	 		dincome_top1_1_5lag
	local var3	 		dllp_1_5lag
	local var4	 		
	local var5	 		
	local var6	 		
	local var7	 		
	local CFE			
	local subset		
	local restricted	horse
	local controls		
	prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"

	#delimit ;
	*** inequality;
	esttab dlloansr dincome_top1 dllp dincome_top1_cr dllp_cr cr_top1_LP using "Tables/$today/Credit_Income1_LP_horserace.tex", replace se 
	nocons nogaps eqlabels(none) label nonumbers nomtitles
	drop(d* _cons)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(space
		  dlloansr_coef
		  dlloansr_coef_se
		  mfxdlloansr
		  space
		  dincome_top1_coef
		  dincome_top1_coef_se
		  mfxdincome_top1
		  space
		  dllp_coef
		  dllp_coef_se
		  mfxdllp
		  space
		  hline
		  Ncrisis
		  Num
		  groups
		  R_2
		  area1 
		  seroc
		  space
		  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3) 
	l(" "
	  "$\Delta_4 \mathrm{log(Credit)_{t-1}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{Income \ Share \ 1 \%_{t-1}} $"
	  " "
	  " "
	  " "
	  "$\Delta_4 \mathrm{log(LP)_{t-1}} $"
	  " "
	  " "
	  " "
	  "\hline"
	  "Number of crises"
	  "Observations" 
	  "Countries" 
	  "Pseudo R$^2$"
	  "AUROC" 
	  " "
	  "\"
	  )) ;
	#delimit cr;

	eststo clear
	
	restore
}
*
*******************
** AUROC figures **
*******************

if `figures_B1_B3' == 1 | `RUN_ALL' == 1 {
	
	cd "$root"
	preserve
	
		**** Must copy the results from the log file and paste into excel
		cap drop *_sample
		capture log close
		
		foreach var in lloansr income_top1 income_top10 llp ltfp_util {
			
			gen d`var'_1_5lag = L1.`var' - L5.`var'
			
		}
		
		quietly {
			*** create same-sample indicators
			* inequality
			logit crisisJST dlloansr_1_5lag dincome_top1_1_5lag dincome_top10_1_5lag ccode*,  vce(robust)
			gen dincome_top1_sample = e(sample)
			gen dlloansr_ineq_sample = e(sample)
			
			* productivity
			logit crisisJST dlloansr_1_5lag dltfp_util_1_5lag dllp_1_5lag ccode*,  vce(robust)
			gen dllp_sample = e(sample)
			gen dlloansr_prod_sample = e(sample)
			
			* regression vars
			gen dlloansr_prod_1_5lag = dlloansr_1_5lag
			gen dlloansr_ineq_1_5lag = dlloansr_1_5lag
		}
		
		foreach var in dlloansr_prod dllp dlloansr_ineq dincome_top1 {
			qui logit crisisJST `var'_1_5lag ccode* if `var'_sample==1,  vce(robust)

			qui predict temp if e(sample)
			
			di as error "****************************************************************"
			di as error "AUROC figure data for model with `var'"
			di as error "****************************************************************"
			log using "$root/Prediction/Temp Files/AUROC_`var'.txt", replace
			roctab crisisJST temp if e(sample), detail /*graph*/
			capture log close
			
			drop temp
		}
		
		foreach var in dlloansr_prod dllp dlloansr_ineq dincome_top1 {
			import delimited "$root/Prediction/Temp Files/AUROC_`var'.txt", delim(" ") clear rowrange(13:1800)
			keep v7 v8 v9 v10 v11 v12 v13
			
			gen sensitivity = v7 if v7!="" & substr(v7,-1,1)!="}"
			replace sensitivity = v8 if mi(sensitivity) & v7==""
			replace sensitivity = v9 if mi(sensitivity) & v8==""
			replace sensitivity = v10 if mi(sensitivity) & v9==""
			
			gen specificity = v11 if v11!="" & substr(v11,-1,1)!="}"
			replace specificity = v12 if mi(specificity) & v11==""
			replace specificity = v13 if mi(specificity) & v12==""
			
			foreach v of varlist s* {
				replace `v' = subinstr(`v',"%{col","",.)
				destring `v', replace force
				replace `v' = `v'/100
			}
			
			keep s*
			drop if mi(sensitivity)
			
			gen one_minus_specificity = 1 - specificity

			export delimited "$root/Prediction/Temp Files/AUROC_`var'.csv", replace novar
		}
	
	restore
}
