
*********************************************************************************
**** Historical Patterns of Inequality and Productivity around Financial Crises
**** by Pascal Paul
**** December 2021
**** This File: Analysis of Trend vs. Cycle Part
*********************************************************************************

set mem 400m
set more off
clear all
clear mata
clear matrix
eststo clear

global root "C:\Users\l1pxp07\Desktop\December 2021"
cd "$root"

//locals for which regressions to run
*** Process data
local process_data				= 0 // Run data processing programs
global exclude_wars 			= 1 // Exclude wars from data

*** Regressions and tables
local Run_ham_filter 			= 1 // Run Hamilton Filter (real-time)

if `process_data' == 1 {
	do "$root/Data/Programs/PROCESS_ALL_DATA.do"
}

include "$root/Trend vs. Cycle/prediction_regression_estimation.do"
use "$root/Data/Output/Dataset_trend_cycle.dta", clear

sort ccode year
xtset ccode year

eststo clear

*****************************************
******** Trend vs. Cycle Tables *********
*****************************************

cd "$root/Trend vs. Cycle/"

*********************
** Hamilton-Filter **
*********************

if `Run_ham_filter' == 1 {
	
	preserve
	
	global vars_levels lrstocks lhpr lloansr cay llp ltfp_util income_top1
	
	sort ccode year
	xtset ccode year
	
	save "$root/Trend vs. Cycle/Temp Files/temp_save_data.dta", replace
	do "$root/Trend vs. Cycle/hamilton_filter.do"
	use "$root/Trend vs. Cycle/Temp Files/temp_save_data.dta", clear
	
	sort ccode year
	xtset ccode year
	
	foreach var in $vars_levels {
		
		merge 1:1 iso year using "$root/Trend vs. Cycle/Temp Files/ham_`var'.dta", nogen
	
	}
	
	sort ccode year
	xtset ccode year
	
	foreach var in $vars_levels {

		gen d`var'_1_5lag = L1.`var' - L5.`var'
		
	}
	
	gen dcycle = .
	gen dtrend = .
	
	foreach var in $vars_levels {
	
			replace dcycle   = d`var'_cyc_1_5lag
			replace dtrend   = d`var'_trend_1_5lag
			
			logit crisisJST dcycle dtrend d`var'_1_5lag ccode*
			gen temp_sample = e(sample)
			
			local name 			`var'_ham_reg
			local model			logit
			local depvar 		crisisJST
			local var1	 		dcycle
			local var2	 		dtrend
			local var3	 		
			local var4	 		
			local var5	 		
			local var6	 		
			local var7	 		
			local CFE			ccode*
			local subset		
			local restricted	temp
			local controls		
			prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
		
			drop temp_sample
		}
		
		gen dgrowth = .
			
		foreach var in $vars_levels {
		
			replace dgrowth  = d`var'_1_5lag
			replace dcycle   = d`var'_cyc_1_5lag
			replace dtrend   = d`var'_trend_1_5lag
			
			logit crisisJST dcycle dtrend d`var'_1_5lag ccode*
			gen temp_sample = e(sample)
		
			local name 			`var'_reg
			local model			logit
			local depvar 		crisisJST
			local var1	 		dgrowth
			local var2	 		
			local var3	 		
			local var4	 		
			local var5	 		
			local var6	 		
			local var7	 		
			local CFE			ccode*
			local subset		
			local restricted	temp
			local controls		
			prediction_regression_estimation "`model'" "`depvar'" "`var1'" "`var2'" "`var3'" "`var4'" "`var5'" "`var6'" "`var7'" "`CFE'" "`subset'" "`restricted'" "`controls'" "`name'"
			
			drop temp_sample
			
		}
		
		#delimit;
		esttab lrstocks_reg lrstocks_ham_reg lhpr_reg lhpr_ham_reg lloansr_reg lloansr_ham_reg cay_reg cay_ham_reg using "Tables/HAM_filter_1.tex", replace se 
		mgroups("Stock Prices" "House Prices" "Credit" "Current Account", pattern(1 1 1 1) span prefix(\multicolumn{2}{c}{) suffix(}))
		nomtitle nocons nogaps eqlabels(none) label nonumbers
		drop(d* ccode* *ccode _cons)
		star(* 0.1 ** 0.05 *** 0.01)
		stats(space
			  dgrowth_coef
			  dgrowth_coef_se
			  mfxdgrowth
			  space
			  dcycle_coef
			  dcycle_coef_se
			  mfxdcycle
			  space
			  dtrend_coef
			  dtrend_coef_se
			  mfxdtrend
			  space
			  hline
			  Ncrisis
			  Num
			  groups
			  cfe
			  pFcountry
			  R_2
			  area1 
			  seroc 
			  space
			  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3)
		l(" "
		  "$\Delta_4 \mathrm{(.)_{t-1}}$"
		  " "
		  " "
		  " "
		  "$ \mathrm{Cycle}$"
		  " "
		  " "
		  " "
		  "$ \mathrm{Trend}$"
		  " "
		  " "
		  " "
		  "\hline"
		  "Number of crises"
		  "Observations" 
		  "Countries"
		  "Country FE"
		  "\textcolor{white}{***}\textit{p-value}" 
		  "Pseudo R$^2$"
		  "AUROC" 
		  " "
		  "\"
		  )) ;
		  
		esttab llp_reg llp_ham_reg ltfp_util_reg ltfp_util_ham_reg income_top1_reg income_top1_ham_reg using "Tables/HAM_filter_2.tex", replace se 
		mgroups("Labor Productivity" "Util.-adj. TFP" "Top1\% Share", pattern(1 1 1) span prefix(\multicolumn{2}{c}{) suffix(}))
		nomtitle nocons nogaps eqlabels(none) label nonumbers
		drop(d* ccode* *ccode _cons)
		star(* 0.1 ** 0.05 *** 0.01)
		stats(space
			  dgrowth_coef
			  dgrowth_coef_se
			  mfxdgrowth
			  space
			  dcycle_coef
			  dcycle_coef_se
			  mfxdcycle
			  space
			  dtrend_coef
			  dtrend_coef_se
			  mfxdtrend
			  space
			  hline
			  Ncrisis
			  Num
			  groups
			  cfe
			  pFcountry
			  R_2
			  area1 
			  seroc 
			  space
			  , 
		  layout(@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @) 
			 fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 0 0 0 3 3 3 3 3 3)
		l(" "
		  "$\Delta_4 \mathrm{(.)_{t-1}}$"
		  " "
		  " "
		  " "
		  "$ \mathrm{Cycle}$"
		  " "
		  " "
		  " "
		  "$ \mathrm{Trend}$"
		  " "
		  " "
		  " "
		  "\hline"
		  "Number of crises"
		  "Observations" 
		  "Countries"
		  "Country FE"
		  "\textcolor{white}{***}\textit{p-value}" 
		  "Pseudo R$^2$"
		  "AUROC" 
		  " "
		  "\"
		  )) ;
	#delimit cr;
	
	eststo clear
	
	restore
	
}
