
clear programs
set more off

program prediction_regression_estimation
	args model depvar v1 v2 v3 v4 v5 v6 v7 CFE subset restricted controls name
	
	local stop = 0
	
	forvalues x = 1/7 {
		local x1 = `x' + 1
		forvalues y = `x1'/7 {
			if "`v`y''"=="`v`x''" & "`v`y''"!="" & "`v`x''"!="" {
				di as error "variable `x' and variable `y' are the same: variable `x': `v`x'', variable `y': `v`y''"
				local stop = 1
			}
		}
	}
	
	if `stop'==0 {
		di as error "logit regression: `depvar' on `v1' `v2' `v3' `v4' `v5' `v6' `v7' `CFE', `subset', `controls'"
		
		preserve
		
		local window 
		forvalues x = 1/7 {
			local var`x' ""
			local est`x'
			if "`v`x''"!="" {
				local win ""
				if strpos("`v`x''","_1_")>0 & strpos("`v`x''","lag")>0 {
					local var`x' = substr("`v`x''",1,strpos("`v`x''","_1_")-1)
					local win = substr("`v`x''",strpos("`v`x''","lag")-1,1)
				}
				else {
					local var`x' = "`v`x''"
				}
				
				local est`x'
				if "`var`x''"=="dlloansr"			local est`x' = "cred`win'"
				if "`var`x''"=="dloansgdp"			local est`x' = "lngdp`win'"
				if "`var`x''"=="dlrgdp"				local est`x' = "GDP`win'"
				if "`var`x''"=="dltfp"				local est`x' = "TFP`win'"
				if "`var`x''"=="dltfp_util"			local est`x' = "TFPutil`win'"
				if "`var`x''"=="dllp"				local est`x' = "LP`win'"
				if "`var`x''"=="dincome_top1"		local est`x' = "T1`win'"
				if "`var`x''"=="dincome_top10"		local est`x' = "T10`win'"
				if "`var`x''"=="dlincome_top1"		local est`x' = "lT1`win'"
				if "`var`x''"=="dlincome_top10"		local est`x' = "lT10`win'"
				if "`var`x''"=="dwealth_income"		local est`x' = "dWI`win'"
				if "`var`x''"=="dlwealth_income"	local est`x' = "dlWI`win'"
				if "`var`x''"=="dlhpr"				local est`x' = "hpr`win'"
				if "`var`x''"=="dlrstocks"			local est`x' = "rstk`win'"
				if "`var`x''"=="dcay"				local est`x' = "cay`win'"
				if "`var`x''"=="dlcar"				local est`x' = "ca`win'"
				if "`var`x''"=="diy"				local est`x' = "iy`win'"
				if "`var`x''"=="dlriy"				local est`x' = "i`win'"
				if "`var`x''"=="dstir"				local est`x' = "stir`win'"
				if "`var`x''"=="Lcay_neg"			local est`x' = "LcayN`win'"
				if "`var`x''"=="Lcay"				local est`x' = "Lcay`win'"
				if "`var`x''"=="rstocks_loansr"		local est`x' = "rst_cr`win'"
			}
		}
		
		if "`subset'"=="xUSA" {
			drop if iso=="USA"
		}
		if "`subset'"=="PrWW2" {
			keep if era=="PreWW2"
		}
		if "`subset'"=="PoWW2" {
			keep if era=="PostWW2"
		}
		if "`subset'"=="xGR" {
			drop if gr==1
		}
		if "`subset'"=="xGDGR" {
			drop if gr==1 | gtdep==1
		}
		if "`subset'"=="1875_2012" {
			keep if year>=1875 & year<=2012
		}
		if "`subset'"=="1947_2012" {
			keep if year>=1947 & year<=2012
		}
		if "`subset'"=="1974_2012" {
			keep if year>=1974 & year<=2012
		}
		
		if "`restricted'"=="prod" {
			local restrict =  "if prod_sample==1"
		}
		if "`restricted'"=="ineq" {
			local restrict =  "if ineq_sample==1"
		}
		if "`restricted'"=="temp" {
			local restrict =  "if temp_sample==1"
		}
		if "`restricted'"=="WI" {
			local restrict =  "if wealth_income_sample==1"
		}
		if "`restricted'"=="horse" {
			local restrict =  "if horse_sample==1"
		}
		
		local D
		if "`depvar'"=="crisisJST"			local D = "C"
		if "`depvar'"=="pk_fin"				local D = "F"
		if "`depvar'"=="pk_norm"			local D = "N"
		if "`depvar'"=="norm_vs_fin"		local D = "NF"
		if "`depvar'"=="crisisJST_t_t1"		local D = "Ct1"
		if "`depvar'"=="crisisJST_t_t1_t2"	local D = "Ct2"
		
		local noCFE
		if "`CFE'"=="" {
			local noCFE = "noCFE"
		}
		
		local m
		if "`model'"=="logit" {
			local m = "l"
		}
		if inlist("`model'","reg","regress") {
			local m = "o"
		}
		
		local control_vars
		local timetrend_included = 0
		if "`controls'"!="" {
			foreach var of local controls {
				local control_vars = "`control_vars' `var'"
				if "`var'"=="time_trend" {
					local timetrend_included = 1
				}
			}
		}
	
		*local list "dlloansr dltfp dltfp_util dllp dincome_top1 dincome_top10 dlincome_top1 dlincome_top10"
		*local rlist "dlrgdp dltfp dltfp_util dllp dstir dltrate drstir dlpc dloansgdp diy dcay dlhpr dlstocks dlrstocks dlX dlfirmloansr dlhhloansr dlmortloansr dlnmortloansr dwealth_income dlwealth_income ddebtgdp"
		
		qui `model' `depvar' `v1' `v2' `v3' `v4' `v5' `v6' `v7' `CFE' `control_vars' `restrict' , vce(robust)
		foreach var in `v1' `v2' `v3' `v4' `v5' `v6' `v7' `control_vars' {
			if "`var'"!="time_trend" {
				sum `var' if e(sample)
				replace `var' = `var'/`r(sd)'
			}
		}

		`model' `depvar' `v1' `v2' `v3' `v4' `v5' `v6' `v7' `CFE' `control_vars' `restrict' , vce(robust)
			sum `depvar' if e(sample)
			local Ncrisis = r(sum)
			
			forvalues x = 1/7 {
				local coef`x'
				local coef`x'_se
				local p_coef`x'
				
				if "`var`x''"!="" {
					testparm `v`x''
					local coef`x' = _b[`v`x'']
					local coef`x'_se = _se[`v`x'']
					local p_coef`x' = r(p)
					local coef`x'_star
					if `p_coef`x''<0.1 {
						local coef`x'_star "*"
					}
					if `p_coef`x''<0.05 {
						local coef`x'_star "**"
					}
					if `p_coef`x''<0.01 {
						local coef`x'_star "***"
					}
				}
			}
			
			local timetrend_coef
			local timetrend_coef_se
			local p_timetrend
			local timetrend_star
			if `timetrend_included'==1 {
				testparm time_trend
				local timetrend_coef = _b[time_trend]
				local timetrend_coef_se = _se[time_trend]
				local p_timetrend = r(p)
				local timetrend_star
				if `p_timetrend'<0.1 {
					local timetrend_star "*"
				}
				if `p_timetrend'<0.05 {
					local timetrend_star "**"
				}
				if `p_timetrend'<0.01 {
					local timetrend_star "***"
				}
			}

			if "`model'"=="logit" {
				local pseud = e(r2_p)
				local ll = e(ll)
				local Ftest = e(chi2)
				local df = e(df_m)
				local pFtest = chi2tail(`df',`Ftest')
				local fstar
				if `pFtest'<0.1 {
					local fstar "*"
				}
				if `pFtest'<0.05 {
					local fstar "**"
				}
				if `pFtest'<0.01 {
					local fstar "***"
				}
			}
			
			if "`model'"=="reg" {
				local pseud = `e(r2)'
				local ll = " "
				local Ftest = e(F)
				local pFtest = Ftail(e(df_m),e(df_r),e(F))
				local fstar
				if `pFtest'<0.1 {
					local fstar "*"
				}
				if `pFtest'<0.05 {
					local fstar "**"
				}
				if `pFtest'<0.01 {
					local fstar "***"
				}
			}
			
			if "`CFE'"!="" {
				if "`model'"=="logit" {
					testparm ccode*
					local F_country = r(chi2)
					local p_country = r(p)
					local countrystar
					if `p_country'<0.1 {
						local countrystar "*"
					}
					if `p_country'<0.05 {
						local countrystar "**"
					}
					if `p_country'<0.01 {
						local countrystar "***"
					}
				}
				if "`model'"=="reg" {
					testparm ccode*
					local F_country = r(F)
					local p_country = r(p)
					local countrystar
					if `p_country'<0.1 {
						local countrystar "*"
					}
					if `p_country'<0.05 {
						local countrystar "**"
					}
					if `p_country'<0.01 {
						local countrystar "***"
					}
				}
			}
			
			if inlist("`depvar'","crisisJST","pk_fin","pk_norm","norm_vs_fin","crisisJST_t_t1","crisisJST_t_t1_t2")==1 {
				predict temp if e(sample), xb
				roctab `depvar' temp if e(sample)
				local area1 = r(area)
				local seroc = r(se)
				local z = (r(area)-0.5)/r(se)
				local parea1=2*normal(-abs(`z'))
				local aurocstar 
				if `parea1'<0.1 {
					local aurocstar "*"
				}
				if `parea1'<0.05 {
					local aurocstar "**"
				}
				if `parea1'<0.01 {
					local aurocstar "***"
				}
			}

			if "`model'"=="logit" {
				forvalues x = 1/7 {
					if "`var`x''"!="" {
						margins, atmeans dydx(`v`x'')
						matrix r=r(b)
						local mfx`var`x''=r[1,1]
					}
				}
			}
			
			cap drop groups max
			local groups
			egen groups=group(ccode) if e(sample)
			egen max=max(groups)
			local groups=max 
			drop groups max
			
			*** code added to center and align all numbers in column
			forvalues x = 1/7 {
				if "`var`x''"!="" {
					local coef`x'_neg "-"
					local coef`x'_neg_SE "-"
					local coef`x'_neg_se ""
					if `coef`x''<0 {
						local coef`x'_neg ""
						if length("`coef`x'_star'")>0{
							local coef`x'_neg_se "*"
						}
					}
				}
				local coef`x'_star_add = "`coef`x'_star'"
				if "`var`x''"!="" {
					if `coef`x''<0 {
						local coef`x'_star_add = substr("`coef`x'_star'",1,length("`coef`x'_star'")-1)
					}
				}
				local coef`x'_star_addm = "`coef`x'_star'"
			}
			if `timetrend_included'==1 {
				local timetrend_neg "-"
				local timetrend_neg_SE "-"
				local timetrend_neg_se ""
				if `timetrend_coef'<0 {
					local timetrend_neg ""
					if length("`timetrend_star'")>0{
						local timetrend_neg_se "*"
					}
				}
			}
			local timetrend_star_add = "`timetrend_star'"
			if `timetrend_included'==1 {
				if `timetrend_coef'<0 {
					local timetrend_star_add = substr("`timetrend_star'",1,length("`timetrend_star'")-1)
				}
			}
			local timetrend_star_addm = "`timetrend_star'"
			
			forvalues x = 1/7 {
				local star_add`x'
			}
			local Tstar_add
			local Cstar_add
			local Fstar_add
			local Astar_add

			#delimit ;
			forvalues x = 1/7 {;
				if length("`coef`x'_star'")>=length("`coef1_star'") 
				 & length("`coef`x'_star'")>=length("`coef2_star'") 
				 & length("`coef`x'_star'")>=length("`coef3_star'") 
				 & length("`coef`x'_star'")>=length("`coef4_star'") 
				 & length("`coef`x'_star'")>=length("`coef5_star'") 
				 & length("`coef`x'_star'")>=length("`coef6_star'") 
				 & length("`coef`x'_star'")>=length("`coef7_star'") 
				 & length("`coef`x'_star'")>=length("`timetrend_star'") 
				 & length("`coef`x'_star'")>=length("`countrystar'") 
				 & length("`coef`x'_star'")>=length("`fstar'") 
				 & length("`coef`x'_star'")>=length("`aurocstar'") {;
					local star1_add ;
					local star2_add ;
					local star3_add ;
					local star4_add ;
					local star5_add ;
					local star6_add ;
					local star7_add ;
					local Tstar_add ;
					local Cstar_add ;
					local Fstar_add ;
					local Astar_add ;
					
					forvalues y = 1/7 {;
						local length`y' = length("`coef`x'_star'")-length("`coef`y'_star'");
						forvalues i = 1/`length`y'' {;
							local star`y'_add = "`star`y'_add'*";
						};
					};
					local lengthT = length("`coef`x'_star'")-length("`timetrend_star'");
					forvalues i = 1/`lengthT' {;
						local Tstar_add = "`Tstar_add'*";
					};
					local lengthC = length("`coef`x'_star'")-length("`countrystar'");
					forvalues i = 1/`lengthC' {;
						local Cstar_add = "`Cstar_add'*";
					};
					local lengthF = length("`coef`x'_star'")-length("`fstar'");
					forvalues i = 1/`lengthF' {;
						local Fstar_add = "`Fstar_add'*";
					};
					local lengthA = length("`coef`x'_star'")-length("`aurocstar'");
					forvalues i = 1/`lengthA' {;
						local Astar_add = "`Astar_add'*";
					};
				};
			};
			foreach x in timetrend_star countrystar fstar aurocstar {;
				if length("``x''")>=length("`coef1_star'") 
				 & length("``x''")>=length("`coef2_star'") 
				 & length("``x''")>=length("`coef3_star'") 
				 & length("``x''")>=length("`coef4_star'") 
				 & length("``x''")>=length("`coef5_star'") 
				 & length("``x''")>=length("`coef6_star'") 
				 & length("``x''")>=length("`coef7_star'") 
				 & length("``x''")>=length("``x''") 
				 & length("``x''")>=length("`fstar'") 
				 & length("``x''")>=length("`aurocstar'") {;
					local star1_add ;
					local star2_add ;
					local star3_add ;
					local star4_add ;
					local star5_add ;
					local star6_add ;
					local star7_add ;
					local Tstar_add ;
					local Cstar_add ;
					local Fstar_add ;
					local Astar_add ;
					
					forvalues y = 1/7 {;
						local length`y' = length("``x''")-length("`coef`y'_star'");
						forvalues i = 1/`length`y'' {;
							local star`y'_add = "`star`y'_add'*";
						};
					};
					local lengthT = length("``x''")-length("`timetrend_star'");
					forvalues i = 1/`lengthT' {;
						local Tstar_add = "`Tstar_add'*";
					};
					local lengthC = length("``x''")-length("`countrystar'");
					forvalues i = 1/`lengthC' {;
						local Cstar_add = "`Cstar_add'*";
					};
					local lengthF = length("``x''")-length("`fstar'");
					forvalues i = 1/`lengthF' {;
						local Fstar_add = "`Fstar_add'*";
					};
					local lengthA = length("``x''")-length("`aurocstar'");
					forvalues i = 1/`lengthA' {;
						local Astar_add = "`Astar_add'*";
					};
				};
			};
			
			local max_star = max(length("`star1_add'"),length("`star2_add'"),
								length("`star3_add'"),length("`star4_add'"),
								length("`star5_add'"),length("`star6_add'"),
								length("`star7_add'"),length("`Tstar_add'"),length("`Cstar_add'"),
								length("`Fstar_add'"),length("`Astar_add'"));
			#delimit cr;
			local model_stars ""
			forvalues t = 1/`max_star' {
				local model_stars = "`model_stars'*"
			}
			
			estadd local Ncrisis 	= "\multicolumn{1}{c}{\textcolor{white}{-}`Ncrisis'\textcolor{white}{`model_stars'}}"
			estadd local Num 		= "\multicolumn{1}{c}{\textcolor{white}{-}`e(N)'\textcolor{white}{`model_stars'}}"
			estadd local groups 	= "\multicolumn{1}{c}{\textcolor{white}{-}`groups'\textcolor{white}{`model_stars'}}"
			
			forvalues x = 1/7 {
				if "`var`x''"!="" {
					estadd local `var`x''_coef 	= "\textcolor{white}{`coef`x'_neg'}`:di %4.3f `coef`x'''`coef`x'_star'\textcolor{white}{`star`x'_add'}"
					estadd local `var`x''_coef_se 	= "\textcolor{white}{`coef`x'_neg_SE'}(`:di %4.3f `coef`x'_se'')\textcolor{white}{`coef`x'_star_add'`star`x'_add'`coef`x'_neg_se'}"
					if "`model'"=="logit" {
						estadd local mfx`var`x'' = "\textcolor{white}{`coef`x'_neg'}[`:di %4.3f `mfx`var`x'''']\textcolor{white}{`coef`x'_star_addm'`star`x'_add'}"
					}
					if "`model'"=="reg" {
						estadd local mfx`var`x'' = " "
					}
				}
			}
			
			/*foreach v of local list {
				if "`v'"!="`var1'" & "`v'"!="`var2'" & "`v'"!="`var3'" & "`v'"!="`var4'" & "`v'"!="`var5'" & "`v'"!="`var6'" & "`v'"!="`var7'" {
					estadd local `v'_coef 		= " "
					estadd local `v'_coef_se 	= " "
					estadd local mfx`v'			= " "
				}
			}
			foreach r of local rlist {
				if "`r'"!="`var1'" & "`r'"!="`var2'" & "`r'"!="`var3'" & "`r'"!="`var4'" & "`r'"!="`var5'" & "`r'"!="`var6'" & "`r'"!="`var7'" {
					estadd local `r'_coef 		= " "
					estadd local `r'_coef_se 	= " "
					estadd local mfx`r'			= " "
				}
			}*/
			
			if "`CFE'"!=""{
				estadd local cfe "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
				if `F_country'>=10 {
					estadd local Fcountry = "\textcolor{white}{-}`:di %4.3f `F_country''`countrystar'\textcolor{white}{`Cstar_add'*}" 
				}
				if `F_country'< 10 {
					estadd local Fcountry = "\textcolor{white}{-}`:di %4.3f `F_country''`countrystar'\textcolor{white}{`Cstar_add'}" 
				}
				estadd local pFcountry = "\textcolor{white}{-}`:di %4.3f `p_country''\textcolor{white}{`countrystar'`Cstar_add'}"
			}
			if "`CFE'"==""{
				estadd local cfe = " "
				estadd local Fcountry = " " 
				estadd local pFcountry = " "
			}
			
			if "`model'"=="logit" {
				if `ll'<=-100 {
					estadd local pLH = "\textcolor{white}{-}`:di %6.3f `ll''\textcolor{white}{`model_stars'***}"
				}
				if `ll'>-100 {
					estadd local pLH = "\textcolor{white}{-}`:di %6.3f `ll''\textcolor{white}{`model_stars'**}"
				}
			}
			if "`model'"=="reg" {
				estadd local pLH = " "
			}
			
			if `Ftest'>=10 {
				estadd local Ftest = "\textcolor{white}{-}`:di %4.3f `Ftest''`fstar'\textcolor{white}{`Fstar_add'*}"
			}
			if `Ftest'<10 {
				estadd local Ftest = "\textcolor{white}{-}`:di %4.3f `Ftest''`fstar'\textcolor{white}{`Fstar_add'}"
			}
			estadd local pFtest = "\textcolor{white}{-}`:di %4.3f `pFtest''\textcolor{white}{`fstar'`Fstar_add'}"
			
			estadd local R_2 = "\textcolor{white}{-}`:di %4.3f `pseud''\textcolor{white}{`model_stars'}"
			
			estadd local area1 = "\textcolor{white}{-}`:di %4.3f `area1''`aurocstar'\textcolor{white}{`Astar_add'}"
			estadd local seroc = "\textcolor{white}{-}(`:di %4.3f `seroc'')\textcolor{white}{`aurocstar'`Astar_add'}"
			
			estadd local space = " "
			estadd local hline = ""
			
			if "`controls'"!="" {
				if `timetrend_included'==1 {
					estadd local timetrend "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
					estadd local timetrend_coef 	= "\textcolor{white}{`timetrend_neg'}`:di %4.3f `timetrend_coef''`timetrend_star'\textcolor{white}{`Tstar_add'}"
					estadd local timetrend_coef_se 	= "\textcolor{white}{`timetrend_neg_SE'}(`:di %4.3f `timetrend_coef_se'')\textcolor{white}{`timetrend_star_add'`Tstar_add'`timetrend_neg_se'}"
				}

				if trim("`controls'")==trim("dlloansr_1_5lag dlpc_1_5lag diy_1_5lag dstir_1_5lag dltrate_1_5lag dcay_1_5lag ddebtgdp_1_5lag") {
					estadd local controls "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
					estadd local stkhpcont " "
					estadd local incT1cont " "
					estadd local gdpcont " "
				}
				if trim("`controls'")==trim("dlloansr_1_5lag dlpc_1_5lag diy_1_5lag dstir_1_5lag dltrate_1_5lag dcay_1_5lag ddebtgdp_1_5lag dlrgdp_1_5lag dlGl_rGDP_1_5lag") {
					estadd local controls "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
					estadd local stkhpcont " "
					estadd local incT1cont " "
					estadd local gdpcont "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
				}
				if trim("`controls'")==trim("dlloansr_1_5lag dlpc_1_5lag diy_1_5lag dstir_1_5lag dltrate_1_5lag dcay_1_5lag ddebtgdp_1_5lag dlrgdp_1_5lag dlGl_rGDP_1_5lag dlhpr_1_5lag dlrstocks_1_5lag") {
					estadd local controls "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
					estadd local stkhpcont "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
					estadd local incT1cont " "
					estadd local gdpcont "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
				}
				if trim("`controls'")==trim("dlloansr_1_5lag dlpc_1_5lag diy_1_5lag dstir_1_5lag dltrate_1_5lag dcay_1_5lag ddebtgdp_1_5lag dlhpr_1_5lag dlrstocks_1_5lag") {
					estadd local controls "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
					estadd local stkhpcont "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
					estadd local incT1cont " "
					estadd local gdpcont " "
				}
				if trim("`controls'")==trim("dlloansr_1_5lag dlpc_1_5lag diy_1_5lag dstir_1_5lag dltrate_1_5lag dcay_1_5lag ddebtgdp_1_5lag dlhpr_1_5lag dlrstocks_1_5lag dincome_top1_1_5lag") {
					estadd local controls "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
					estadd local stkhpcont "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
					estadd local incT1cont "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
					estadd local gdpcont " "
				}
				if trim("`controls'")==trim("dlloansr_1_5lag dlhpr_1_5lag dlrstocks_1_5lag") {
					estadd local cr_sp_hp "\multicolumn{1}{c}{\textcolor{white}{-}\checkmark\textcolor{white}{`model_stars'}}"
				}
			}
			
			*eststo `D'`m'`est1'`est2'`est3'`est4'`est5'`est6'`est7'`subset'`noCFE'`res'`cont'
			eststo `name'
			
		restore
	}
end
